# dupr-backend
Internal RESTful APIs to access DUPR ratings, users and provide matches.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1.0.0
- Package version: 1.0.0
- Generator version: 7.16.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import dupr_backend
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import dupr_backend
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import dupr_backend
from dupr_backend.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.dupr.gg
# See configuration.py for a list of all supported configuration parameters.
configuration = dupr_backend.Configuration(
    host = "https://api.dupr.gg"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): bearerAuth
configuration = dupr_backend.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with dupr_backend.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = dupr_backend.ActivityAdminNewsfeedsFeaturesApi(api_client)
    version = 'v1.0' # str |  (default to 'v1.0')
    user_suggestion_request = dupr_backend.UserSuggestionRequest() # UserSuggestionRequest | 

    try:
        api_response = api_instance.add_user_suggestions(version, user_suggestion_request)
        print("The response of ActivityAdminNewsfeedsFeaturesApi->add_user_suggestions:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ActivityAdminNewsfeedsFeaturesApi->add_user_suggestions: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.dupr.gg*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ActivityAdminNewsfeedsFeaturesApi* | [**add_user_suggestions**](docs/ActivityAdminNewsfeedsFeaturesApi.md#add_user_suggestions) | **POST** /activity/{version}/admin/user-suggestion | 
*ActivityAdminNewsfeedsFeaturesApi* | [**create_post2**](docs/ActivityAdminNewsfeedsFeaturesApi.md#create_post2) | **POST** /activity/{version}/admin/test | 
*ActivityAdminNewsfeedsFeaturesApi* | [**fetch_feeds2**](docs/ActivityAdminNewsfeedsFeaturesApi.md#fetch_feeds2) | **GET** /activity/{version}/admin/test | 
*ActivityAdminNewsfeedsFeaturesApi* | [**follow2**](docs/ActivityAdminNewsfeedsFeaturesApi.md#follow2) | **POST** /activity/{version}/admin/test/follow | 
*ActivityAdminNewsfeedsFeaturesApi* | [**get_user_suggestion**](docs/ActivityAdminNewsfeedsFeaturesApi.md#get_user_suggestion) | **GET** /activity/{version}/admin/user-suggestion | 
*ActivityAdminNewsfeedsFeaturesApi* | [**react2**](docs/ActivityAdminNewsfeedsFeaturesApi.md#react2) | **POST** /activity/{version}/admin/test/react | 
*ActivityAdminNewsfeedsFeaturesApi* | [**remove_user_suggestions**](docs/ActivityAdminNewsfeedsFeaturesApi.md#remove_user_suggestions) | **DELETE** /activity/{version}/admin/user-suggestion | 
*ActivityAdminNewsfeedsFeaturesApi* | [**sync_club_followers**](docs/ActivityAdminNewsfeedsFeaturesApi.md#sync_club_followers) | **POST** /activity/{version}/admin/utils/sync/clubFollowers | 
*ActivityAdminNewsfeedsFeaturesApi* | [**sync_feeds**](docs/ActivityAdminNewsfeedsFeaturesApi.md#sync_feeds) | **POST** /activity/{version}/admin/utils/sync | 
*ActivityAdminNewsfeedsFeaturesApi* | [**unfollow2**](docs/ActivityAdminNewsfeedsFeaturesApi.md#unfollow2) | **DELETE** /activity/{version}/admin/test/follow | 
*ActivityAdminNewsfeedsFeaturesApi* | [**unfollow_clubs_with_same_ids**](docs/ActivityAdminNewsfeedsFeaturesApi.md#unfollow_clubs_with_same_ids) | **POST** /activity/{version}/admin/utils/club-followers/same-id | 
*ActivityNewsfeedsForClubApi* | [**comments1**](docs/ActivityNewsfeedsForClubApi.md#comments1) | **GET** /activity/{version}/club/{feedId}/{postId}/comments | 
*ActivityNewsfeedsForClubApi* | [**create_post1**](docs/ActivityNewsfeedsForClubApi.md#create_post1) | **POST** /activity/{version}/club/{feedId} | 
*ActivityNewsfeedsForClubApi* | [**delete_comment1**](docs/ActivityNewsfeedsForClubApi.md#delete_comment1) | **DELETE** /activity/{version}/club/{feedId}/{postId}/react | 
*ActivityNewsfeedsForClubApi* | [**edit_post1**](docs/ActivityNewsfeedsForClubApi.md#edit_post1) | **PUT** /activity/{version}/club/{feedId}/{postId} | 
*ActivityNewsfeedsForClubApi* | [**fetch_feeds1**](docs/ActivityNewsfeedsForClubApi.md#fetch_feeds1) | **GET** /activity/{version}/club/{feedId} | 
*ActivityNewsfeedsForClubApi* | [**follow1**](docs/ActivityNewsfeedsForClubApi.md#follow1) | **POST** /activity/{version}/club/{feedId}/follow | 
*ActivityNewsfeedsForClubApi* | [**get_pinned_posts**](docs/ActivityNewsfeedsForClubApi.md#get_pinned_posts) | **GET** /activity/{version}/club/{feedId}/pinned | 
*ActivityNewsfeedsForClubApi* | [**get_post_detail1**](docs/ActivityNewsfeedsForClubApi.md#get_post_detail1) | **GET** /activity/{version}/club/{feedId}/{postId} | 
*ActivityNewsfeedsForClubApi* | [**pin_post**](docs/ActivityNewsfeedsForClubApi.md#pin_post) | **POST** /activity/{version}/club/{feedId}/{postId}/pin | 
*ActivityNewsfeedsForClubApi* | [**react1**](docs/ActivityNewsfeedsForClubApi.md#react1) | **POST** /activity/{version}/club/{feedId}/{postId}/react | 
*ActivityNewsfeedsForClubApi* | [**reactions1**](docs/ActivityNewsfeedsForClubApi.md#reactions1) | **GET** /activity/{version}/club/{feedId}/{postId}/reactions | 
*ActivityNewsfeedsForClubApi* | [**remove_post1**](docs/ActivityNewsfeedsForClubApi.md#remove_post1) | **DELETE** /activity/{version}/club/{feedId}/{postId} | 
*ActivityNewsfeedsForClubApi* | [**unfollow1**](docs/ActivityNewsfeedsForClubApi.md#unfollow1) | **DELETE** /activity/{version}/club/{feedId}/follow | 
*ActivityNewsfeedsForClubApi* | [**unpin_post**](docs/ActivityNewsfeedsForClubApi.md#unpin_post) | **DELETE** /activity/{version}/club/{feedId}/{postId}/pin | 
*ActivityNewsfeedsForClubApi* | [**update_comment1**](docs/ActivityNewsfeedsForClubApi.md#update_comment1) | **PUT** /activity/{version}/club/{feedId}/{postId}/react | 
*ActivityNewsfeedsForUserApi* | [**comments**](docs/ActivityNewsfeedsForUserApi.md#comments) | **GET** /activity/{version}/user/{feedId}/{postId}/comments | 
*ActivityNewsfeedsForUserApi* | [**create_post**](docs/ActivityNewsfeedsForUserApi.md#create_post) | **POST** /activity/{version}/user/{feedId} | 
*ActivityNewsfeedsForUserApi* | [**delete_comment**](docs/ActivityNewsfeedsForUserApi.md#delete_comment) | **DELETE** /activity/{version}/user/{feedId}/{postId}/react | 
*ActivityNewsfeedsForUserApi* | [**edit_post**](docs/ActivityNewsfeedsForUserApi.md#edit_post) | **PUT** /activity/{version}/user/{feedId}/{postId} | 
*ActivityNewsfeedsForUserApi* | [**fetch_feeds**](docs/ActivityNewsfeedsForUserApi.md#fetch_feeds) | **GET** /activity/{version}/user/{feedId} | 
*ActivityNewsfeedsForUserApi* | [**follow**](docs/ActivityNewsfeedsForUserApi.md#follow) | **POST** /activity/{version}/user/{feedId}/follow | 
*ActivityNewsfeedsForUserApi* | [**get_following_info**](docs/ActivityNewsfeedsForUserApi.md#get_following_info) | **GET** /activity/{version}/user/{feedId}/followingInfo | 
*ActivityNewsfeedsForUserApi* | [**get_list_followers**](docs/ActivityNewsfeedsForUserApi.md#get_list_followers) | **GET** /activity/{version}/user/{feedId}/followers | 
*ActivityNewsfeedsForUserApi* | [**get_list_followings**](docs/ActivityNewsfeedsForUserApi.md#get_list_followings) | **GET** /activity/{version}/user/{feedId}/followings | 
*ActivityNewsfeedsForUserApi* | [**get_post_detail**](docs/ActivityNewsfeedsForUserApi.md#get_post_detail) | **GET** /activity/{version}/user/{feedId}/{postId} | 
*ActivityNewsfeedsForUserApi* | [**get_user_suggestion1**](docs/ActivityNewsfeedsForUserApi.md#get_user_suggestion1) | **GET** /activity/{version}/user/{feedId}/user-suggestion | 
*ActivityNewsfeedsForUserApi* | [**react**](docs/ActivityNewsfeedsForUserApi.md#react) | **POST** /activity/{version}/user/{feedId}/{postId}/react | 
*ActivityNewsfeedsForUserApi* | [**reactions**](docs/ActivityNewsfeedsForUserApi.md#reactions) | **GET** /activity/{version}/user/{feedId}/{postId}/reactions | 
*ActivityNewsfeedsForUserApi* | [**remove_post**](docs/ActivityNewsfeedsForUserApi.md#remove_post) | **DELETE** /activity/{version}/user/{feedId}/{postId} | 
*ActivityNewsfeedsForUserApi* | [**timeline**](docs/ActivityNewsfeedsForUserApi.md#timeline) | **GET** /activity/{version}/user/{feedId}/timeline | 
*ActivityNewsfeedsForUserApi* | [**unfollow**](docs/ActivityNewsfeedsForUserApi.md#unfollow) | **DELETE** /activity/{version}/user/{feedId}/follow | 
*ActivityNewsfeedsForUserApi* | [**update_comment**](docs/ActivityNewsfeedsForUserApi.md#update_comment) | **PUT** /activity/{version}/user/{feedId}/{postId}/react | 
*AddressApi* | [**autocomplete**](docs/AddressApi.md#autocomplete) | **GET** /address/{version}/autocomplete | 
*AddressApi* | [**delete_user_address**](docs/AddressApi.md#delete_user_address) | **DELETE** /address/{version}/delete | 
*AddressApi* | [**geocode**](docs/AddressApi.md#geocode) | **GET** /address/{version}/geocode | 
*AddressApi* | [**place_details**](docs/AddressApi.md#place_details) | **GET** /address/{version}/details | 
*AddressApi* | [**save_address**](docs/AddressApi.md#save_address) | **PUT** /address/{version}/save | 
*AdminApi* | [**activate_match**](docs/AdminApi.md#activate_match) | **POST** /admin/{version}/panel/match/active | 
*AdminApi* | [**add_key_to_external_client**](docs/AdminApi.md#add_key_to_external_client) | **POST** /admin/{version}/client/keys/add | 
*AdminApi* | [**adjust_rating**](docs/AdminApi.md#adjust_rating) | **PUT** /admin/rating/{version}/edit | 
*AdminApi* | [**admin_verified_match_history**](docs/AdminApi.md#admin_verified_match_history) | **GET** /admin/match/{version}/history | 
*AdminApi* | [**batch_calculated_statistics**](docs/AdminApi.md#batch_calculated_statistics) | **PUT** /admin/calculated/{version}/stats | 
*AdminApi* | [**batch_club_matches**](docs/AdminApi.md#batch_club_matches) | **POST** /admin/{version}/club/{clubId}/match/batch | 
*AdminApi* | [**batch_manual_club_matches**](docs/AdminApi.md#batch_manual_club_matches) | **POST** /admin/{version}/match/club-batch | 
*AdminApi* | [**batch_manual_matches**](docs/AdminApi.md#batch_manual_matches) | **POST** /admin/{version}/match/batch | 
*AdminApi* | [**batch_player_rating**](docs/AdminApi.md#batch_player_rating) | **PUT** /admin/{version}/rating/batch | 
*AdminApi* | [**batch_player_rating_provisional**](docs/AdminApi.md#batch_player_rating_provisional) | **PUT** /admin/{version}/ratings-provisional/batch | 
*AdminApi* | [**batch_set_reliability_scores**](docs/AdminApi.md#batch_set_reliability_scores) | **POST** /admin/{version}/player/batch-reliability-score | 
*AdminApi* | [**block_admin_apis**](docs/AdminApi.md#block_admin_apis) | **PUT** /admin/{version}/panel/block | 
*AdminApi* | [**bulk_delete_matches**](docs/AdminApi.md#bulk_delete_matches) | **PUT** /admin/{version}/match/delete | 
*AdminApi* | [**bulk_grant_entitlements_by_user_id**](docs/AdminApi.md#bulk_grant_entitlements_by_user_id) | **POST** /admin/revenuecat/entitlements/grant/bulk | 
*AdminApi* | [**bulk_reliability_score**](docs/AdminApi.md#bulk_reliability_score) | **PUT** /admin/{version}/player/bulk-reliability-score | 
*AdminApi* | [**bulk_send_coppa_email**](docs/AdminApi.md#bulk_send_coppa_email) | **POST** /admin/{version}/bulkcoppaemail | 
*AdminApi* | [**bulk_send_wrapped_email**](docs/AdminApi.md#bulk_send_wrapped_email) | **POST** /admin/{version}/bulkwrappedemail | 
*AdminApi* | [**bulk_set_club_restrictions**](docs/AdminApi.md#bulk_set_club_restrictions) | **PUT** /admin/{version}/clubs/restrictions/bulk | 
*AdminApi* | [**bulk_upload_pb_com_events**](docs/AdminApi.md#bulk_upload_pb_com_events) | **POST** /admin/{version}/bulkuploadpbcomevents | 
*AdminApi* | [**change_email**](docs/AdminApi.md#change_email) | **PUT** /admin/{version}/panel/email/change | 
*AdminApi* | [**change_role**](docs/AdminApi.md#change_role) | **POST** /admin/{version}/panel/role/change | 
*AdminApi* | [**club_create**](docs/AdminApi.md#club_create) | **PUT** /admin/{version}/clubs/create | 
*AdminApi* | [**create_banner**](docs/AdminApi.md#create_banner) | **POST** /admin/{version}/panel/create/banner | 
*AdminApi* | [**create_clubs_batch**](docs/AdminApi.md#create_clubs_batch) | **PUT** /admin/{version}/clubs/create/batch | 
*AdminApi* | [**create_external_client**](docs/AdminApi.md#create_external_client) | **POST** /admin/{version}/client | 
*AdminApi* | [**decode**](docs/AdminApi.md#decode) | **GET** /admin/decode | 
*AdminApi* | [**delete_club**](docs/AdminApi.md#delete_club) | **DELETE** /admin/{version}/club/{clubId} | 
*AdminApi* | [**delete_match**](docs/AdminApi.md#delete_match) | **POST** /admin/{version}/panel/match/delete | 
*AdminApi* | [**delete_user**](docs/AdminApi.md#delete_user) | **PUT** /admin/{version}/panel/user/delete | 
*AdminApi* | [**delete_wix_user**](docs/AdminApi.md#delete_wix_user) | **DELETE** /admin/wix/{version}/{version}/delete | 
*AdminApi* | [**dupr_id**](docs/AdminApi.md#dupr_id) | **GET** /admin/{version}/panel/user | 
*AdminApi* | [**edit_club_staff**](docs/AdminApi.md#edit_club_staff) | **POST** /admin/club/staff/{version}/edit | 
*AdminApi* | [**encode**](docs/AdminApi.md#encode) | **GET** /admin/encode | 
*AdminApi* | [**export_matches_missing_team_player**](docs/AdminApi.md#export_matches_missing_team_player) | **GET** /admin/{version}/team-players/missing/export | 
*AdminApi* | [**export_provisional_ratings**](docs/AdminApi.md#export_provisional_ratings) | **GET** /admin/datascience/provisional_ratings/export | 
*AdminApi* | [**export_users_via_mail**](docs/AdminApi.md#export_users_via_mail) | **POST** /admin/{version}/panel/user/export | 
*AdminApi* | [**find_duplicated_account_for_players**](docs/AdminApi.md#find_duplicated_account_for_players) | **POST** /admin/{version}/duplicated | 
*AdminApi* | [**get_active_banner**](docs/AdminApi.md#get_active_banner) | **GET** /admin/{version}/panel/get/banner | 
*AdminApi* | [**get_all_banner**](docs/AdminApi.md#get_all_banner) | **GET** /admin/{version}/panel/get/banners | 
*AdminApi* | [**get_all_roles1**](docs/AdminApi.md#get_all_roles1) | **GET** /admin/{version}/roles | 
*AdminApi* | [**get_club_restrictions**](docs/AdminApi.md#get_club_restrictions) | **POST** /admin/{version}/clubs/restrictions | 
*AdminApi* | [**get_club_settings**](docs/AdminApi.md#get_club_settings) | **POST** /admin/{version}/clubs/settings | 
*AdminApi* | [**get_external_client_permissions**](docs/AdminApi.md#get_external_client_permissions) | **POST** /admin/{version}/client/keys | 
*AdminApi* | [**get_external_clients**](docs/AdminApi.md#get_external_clients) | **POST** /admin/{version}/client/batch | 
*AdminApi* | [**get_match1**](docs/AdminApi.md#get_match1) | **GET** /admin/{version}/panel/match/{id} | 
*AdminApi* | [**get_rating_leaderboard**](docs/AdminApi.md#get_rating_leaderboard) | **GET** /admin/{version}/leaderboard/search | 
*AdminApi* | [**get_user_bracket**](docs/AdminApi.md#get_user_bracket) | **POST** /admin/{version}/panel/brackets/user/all | 
*AdminApi* | [**get_user_profile**](docs/AdminApi.md#get_user_profile) | **GET** /admin/{version}/panel/user/profile | 
*AdminApi* | [**grant_entitlements_by_user_id**](docs/AdminApi.md#grant_entitlements_by_user_id) | **POST** /admin/revenuecat/entitlements/grant | 
*AdminApi* | [**index_club_members**](docs/AdminApi.md#index_club_members) | **POST** /admin/{version}/members/index | 
*AdminApi* | [**index_clubs**](docs/AdminApi.md#index_clubs) | **PUT** /admin/{version}/clubs/index | 
*AdminApi* | [**index_player**](docs/AdminApi.md#index_player) | **PATCH** /admin/{version}/index/{id} | 
*AdminApi* | [**index_players**](docs/AdminApi.md#index_players) | **PATCH** /admin/{version}/index | 
*AdminApi* | [**map_csv_to_braze_segment**](docs/AdminApi.md#map_csv_to_braze_segment) | **PUT** /admin/marketing/mapCsvToBrazeSegment | 
*AdminApi* | [**match_codes_export**](docs/AdminApi.md#match_codes_export) | **GET** /admin/{version}/match/export/codes | 
*AdminApi* | [**match_reassign**](docs/AdminApi.md#match_reassign) | **POST** /admin/{version}/match/reassign | 
*AdminApi* | [**match_reassign_batch**](docs/AdminApi.md#match_reassign_batch) | **POST** /admin/{version}/match/reassign/batch | 
*AdminApi* | [**matches_export**](docs/AdminApi.md#matches_export) | **GET** /admin/{version}/match/export | 
*AdminApi* | [**merge_users**](docs/AdminApi.md#merge_users) | **POST** /admin/{version}/panel/merge | 
*AdminApi* | [**merge_users_batch**](docs/AdminApi.md#merge_users_batch) | **POST** /admin/{version}/panel/merge/batch | 
*AdminApi* | [**obfuscate**](docs/AdminApi.md#obfuscate) | **GET** /admin/obfuscate | 
*AdminApi* | [**obfuscate_match_id**](docs/AdminApi.md#obfuscate_match_id) | **GET** /admin/obfuscate-matchid | 
*AdminApi* | [**populate_unknown_player_pre_ratings**](docs/AdminApi.md#populate_unknown_player_pre_ratings) | **POST** /admin/{version}/unknown/players/populate-pre-rating | 
*AdminApi* | [**re_create_es_index**](docs/AdminApi.md#re_create_es_index) | **POST** /admin/{version}/panel/es/{id}/mapping | 
*AdminApi* | [**recalculate_match_elo_ratings_bulk**](docs/AdminApi.md#recalculate_match_elo_ratings_bulk) | **POST** /admin/{version}/match/elo-rating-recalculation | 
*AdminApi* | [**recalculate_pre_match_ratings**](docs/AdminApi.md#recalculate_pre_match_ratings) | **POST** /admin/{version}/match/pre-rating-impact | 
*AdminApi* | [**recalculate_pre_match_ratings1**](docs/AdminApi.md#recalculate_pre_match_ratings1) | **POST** /admin/{version}/match/bulk-pre-rating-impact | 
*AdminApi* | [**remove_all_club_restrictions**](docs/AdminApi.md#remove_all_club_restrictions) | **DELETE** /admin/{version}/clubs/restrictions/all | 
*AdminApi* | [**remove_club_restrictions**](docs/AdminApi.md#remove_club_restrictions) | **DELETE** /admin/{version}/clubs/restrictions | 
*AdminApi* | [**remove_tag_from_shopify_customers**](docs/AdminApi.md#remove_tag_from_shopify_customers) | **DELETE** /admin/subscriptions/shopify/users/tag | 
*AdminApi* | [**reset_client_secret**](docs/AdminApi.md#reset_client_secret) | **GET** /admin/client/{version}/secret/reset | 
*AdminApi* | [**restrict**](docs/AdminApi.md#restrict) | **POST** /admin/{version}/panel/user/{id}/restrict | 
*AdminApi* | [**save_topic**](docs/AdminApi.md#save_topic) | **POST** /admin/{version}/topic | 
*AdminApi* | [**save_verified_match1**](docs/AdminApi.md#save_verified_match1) | **PUT** /admin/match/{version}/save | 
*AdminApi* | [**set_club_restrictions**](docs/AdminApi.md#set_club_restrictions) | **PUT** /admin/{version}/clubs/restrictions | 
*AdminApi* | [**set_club_settings**](docs/AdminApi.md#set_club_settings) | **PUT** /admin/{version}/clubs/settings | 
*AdminApi* | [**set_users_active_by_dupr_id**](docs/AdminApi.md#set_users_active_by_dupr_id) | **POST** /admin/users/enable | 
*AdminApi* | [**set_users_inactive_by_dupr_id**](docs/AdminApi.md#set_users_inactive_by_dupr_id) | **POST** /admin/users/disable | 
*AdminApi* | [**signup**](docs/AdminApi.md#signup) | **PUT** /admin/{version}/panel/user/signup | 
*AdminApi* | [**signup_batch**](docs/AdminApi.md#signup_batch) | **PUT** /admin/{version}/panel/user/signup/batch | 
*AdminApi* | [**trigger_missing_elo_rating_for_players**](docs/AdminApi.md#trigger_missing_elo_rating_for_players) | **POST** /admin/{version}/player-rating-history | 
*AdminApi* | [**unclaim_user**](docs/AdminApi.md#unclaim_user) | **PUT** /admin/{version}/panel/user/unclaim | 
*AdminApi* | [**unobfuscate**](docs/AdminApi.md#unobfuscate) | **GET** /admin/unobfuscate | 
*AdminApi* | [**unobfuscate_match_code**](docs/AdminApi.md#unobfuscate_match_code) | **GET** /admin/unobfuscate-matchcode | 
*AdminApi* | [**update_banner**](docs/AdminApi.md#update_banner) | **PUT** /admin/{version}/panel/update/banner | 
*AdminApi* | [**update_club_currency**](docs/AdminApi.md#update_club_currency) | **PUT** /admin/{version}/club/{clubId}/currency | 
*AdminApi* | [**update_club_revenue_model**](docs/AdminApi.md#update_club_revenue_model) | **PUT** /admin/{version}/club/{clubId}/revenue | 
*AdminApi* | [**update_currency_rates**](docs/AdminApi.md#update_currency_rates) | **GET** /admin/club/currency/{version}/update | 
*AdminApi* | [**update_es_index**](docs/AdminApi.md#update_es_index) | **PUT** /admin/{version}/panel/es/{id}/mapping | 
*AdminApi* | [**update_external_client_permissions**](docs/AdminApi.md#update_external_client_permissions) | **POST** /admin/{version}/client/permissions | 
*AdminApi* | [**update_external_id_cron**](docs/AdminApi.md#update_external_id_cron) | **PUT** /admin/{version}/external-id/bulk | 
*AdminApi* | [**update_lucra_connection1**](docs/AdminApi.md#update_lucra_connection1) | **PUT** /admin/{version}/panel/user/{id}/lucra-connect | 
*AdminApi* | [**update_match**](docs/AdminApi.md#update_match) | **PUT** /admin/{version}/panel/match/{version}/update | 
*AdminApi* | [**update_payment_status**](docs/AdminApi.md#update_payment_status) | **POST** /admin/{version}/panel/brackets/registration/update | 
*AdminApi* | [**update_player_rating**](docs/AdminApi.md#update_player_rating) | **PUT** /admin/{version}/rating/{id} | 
*AdminApi* | [**update_player_statistics**](docs/AdminApi.md#update_player_statistics) | **PUT** /admin/calculated/{version}/stats/update | 
*AdminApi* | [**update_ratings_cron**](docs/AdminApi.md#update_ratings_cron) | **PUT** /admin/{version}/ratings/bulk | 
*AdminApi* | [**update_referral_code**](docs/AdminApi.md#update_referral_code) | **PATCH** /admin/referral-code/{version}/update | 
*AdminApi* | [**update_status**](docs/AdminApi.md#update_status) | **POST** /admin/{version}/panel/user/status | 
*AdminApi* | [**update_user_profile**](docs/AdminApi.md#update_user_profile) | **PUT** /admin/{version}/panel/user/profile | 
*AdminApi* | [**upload_dupr_performance_chart_data**](docs/AdminApi.md#upload_dupr_performance_chart_data) | **PUT** /admin/{version}/panel/performance | 
*AdminApi* | [**upsert_and_tag_shopify_customers**](docs/AdminApi.md#upsert_and_tag_shopify_customers) | **PUT** /admin/subscriptions/shopify/users/tag | 
*AdminApi* | [**user_lookup**](docs/AdminApi.md#user_lookup) | **POST** /admin/{version}/panel/user/lookup | 
*AdminApi* | [**verify_email**](docs/AdminApi.md#verify_email) | **POST** /admin/{version}/panel/email/verify | 
*AdminEventApi* | [**delete_all_league**](docs/AdminEventApi.md#delete_all_league) | **DELETE** /admin/event/{version}/all | 
*AdminEventApi* | [**delete_event_players**](docs/AdminEventApi.md#delete_event_players) | **DELETE** /admin/event/player/{version}/all | 
*AdminEventApi* | [**force_delete_league**](docs/AdminEventApi.md#force_delete_league) | **DELETE** /admin/event/{version}/{leagueId} | 
*AdminEventApi* | [**index_all_leagues**](docs/AdminEventApi.md#index_all_leagues) | **GET** /admin/event/{version}/index | 
*AdminEventApi* | [**index_league_players**](docs/AdminEventApi.md#index_league_players) | **GET** /admin/event/player/{version}/index | 
*AdminEventApi* | [**index_leagues_by_id**](docs/AdminEventApi.md#index_leagues_by_id) | **GET** /admin/event/{leagueId}/{version}/index | 
*AdminEventApi* | [**registered_to_bracket**](docs/AdminEventApi.md#registered_to_bracket) | **POST** /admin/event/{bracketId}/{version}/join | 
*AdminEventApi* | [**restore_deleted_league**](docs/AdminEventApi.md#restore_deleted_league) | **POST** /admin/event/{version}/restore/{leagueId} | 
*AdminEventApi* | [**update_league_fees**](docs/AdminEventApi.md#update_league_fees) | **PUT** /admin/event/{version}/{leagueId}/fees | 
*AnnouncementsApi* | [**draft1**](docs/AnnouncementsApi.md#draft1) | **POST** /event/announcement/{version}/draft | 
*AnnouncementsApi* | [**edit**](docs/AnnouncementsApi.md#edit) | **POST** /event/announcement/{version}/edit | 
*AnnouncementsApi* | [**get_announcements**](docs/AnnouncementsApi.md#get_announcements) | **POST** /event/announcement/{version}/all | 
*AnnouncementsApi* | [**save3**](docs/AnnouncementsApi.md#save3) | **POST** /event/announcement/{version}/save | 
*AnnouncementsApi* | [**sent_notification**](docs/AnnouncementsApi.md#sent_notification) | **POST** /event/announcement/send/{version}/test | 
*AuthenticationApi* | [**device_registration**](docs/AuthenticationApi.md#device_registration) | **PUT** /auth/{version}/device | 
*AuthenticationApi* | [**email_already_exists**](docs/AuthenticationApi.md#email_already_exists) | **GET** /auth/email/{version}/exists | 
*AuthenticationApi* | [**email_exists**](docs/AuthenticationApi.md#email_exists) | **POST** /auth/email/{version}/exists | 
*AuthenticationApi* | [**initiate_reset_password**](docs/AuthenticationApi.md#initiate_reset_password) | **GET** /auth/password/{version}/initiate | 
*AuthenticationApi* | [**login**](docs/AuthenticationApi.md#login) | **POST** /auth/{version}/login | 
*AuthenticationApi* | [**login_read_only_token**](docs/AuthenticationApi.md#login_read_only_token) | **POST** /auth/{version}/login-read-only-token | 
*AuthenticationApi* | [**login_read_only_token_with_full_access_token**](docs/AuthenticationApi.md#login_read_only_token_with_full_access_token) | **POST** /auth/{version}/login-read-only-token-with-session | 
*AuthenticationApi* | [**panel_login**](docs/AuthenticationApi.md#panel_login) | **POST** /auth/panel/{version}/login | 
*AuthenticationApi* | [**refresh_access_token**](docs/AuthenticationApi.md#refresh_access_token) | **GET** /auth/{version}/refresh | 
*AuthenticationApi* | [**register**](docs/AuthenticationApi.md#register) | **POST** /auth/{version}/signup | 
*AuthenticationApi* | [**reset_password1**](docs/AuthenticationApi.md#reset_password1) | **GET** /auth/password/{version}/reset | 
*AuthenticationApi* | [**send_verification_email1**](docs/AuthenticationApi.md#send_verification_email1) | **GET** /auth/email/{version}/resend | 
*AuthenticationApi* | [**validate_ambassador_code**](docs/AuthenticationApi.md#validate_ambassador_code) | **GET** /auth/{version}/validate | 
*AuthenticationApi* | [**verify_email_address1**](docs/AuthenticationApi.md#verify_email_address1) | **GET** /auth/email/{version}/verify | 
*AuthenticationApi* | [**verify_user_email**](docs/AuthenticationApi.md#verify_user_email) | **POST** /auth/email/{version}/verify | 
*BracketsApi* | [**add_match_score**](docs/BracketsApi.md#add_match_score) | **POST** /brackets/match/{version}/save | 
*BracketsApi* | [**add_match_score_by_director**](docs/BracketsApi.md#add_match_score_by_director) | **POST** /brackets/director/match/{version}/save | 
*BracketsApi* | [**confirm_match1**](docs/BracketsApi.md#confirm_match1) | **POST** /brackets/match/{version}/confirm | 
*BracketsApi* | [**confirm_match_director**](docs/BracketsApi.md#confirm_match_director) | **POST** /brackets/director/match/{version}/confirm | 
*BracketsApi* | [**confirm_team_by_director**](docs/BracketsApi.md#confirm_team_by_director) | **POST** /brackets/director/teams/{version}/confirm | 
*BracketsApi* | [**delete_league1**](docs/BracketsApi.md#delete_league1) | **DELETE** /brackets/{version}/{leagueId}/{bracketId} | 
*BracketsApi* | [**edit_bracket**](docs/BracketsApi.md#edit_bracket) | **PUT** /brackets/{version}/edit | 
*BracketsApi* | [**edit_bracket_status**](docs/BracketsApi.md#edit_bracket_status) | **PUT** /brackets/director/{version}/edit/bracket_status | 
*BracketsApi* | [**edit_confirmed_matches**](docs/BracketsApi.md#edit_confirmed_matches) | **POST** /brackets/director/confirm/match/{version}/edit | 
*BracketsApi* | [**edit_match_score**](docs/BracketsApi.md#edit_match_score) | **POST** /brackets/match/{version}/edit | 
*BracketsApi* | [**edit_match_score_by_director**](docs/BracketsApi.md#edit_match_score_by_director) | **POST** /brackets/director/match/{version}/edit | 
*BracketsApi* | [**edit_partner**](docs/BracketsApi.md#edit_partner) | **POST** /brackets/partner/{version}/edit | 
*BracketsApi* | [**edit_player_wait_list**](docs/BracketsApi.md#edit_player_wait_list) | **POST** /brackets/director/waitlist/{version}/edit | 
*BracketsApi* | [**edit_teams**](docs/BracketsApi.md#edit_teams) | **POST** /brackets/director/teams/{version}/edit | 
*BracketsApi* | [**end_league1**](docs/BracketsApi.md#end_league1) | **GET** /brackets/{leagueId}/{bracketId}/{version}/end | 
*BracketsApi* | [**export_bracket_participants**](docs/BracketsApi.md#export_bracket_participants) | **GET** /brackets/director/{bracketId}/participant/{version}/export | 
*BracketsApi* | [**forfeit_match**](docs/BracketsApi.md#forfeit_match) | **POST** /brackets/director/match/{version}/forfeit | 
*BracketsApi* | [**get_all_bracket_matches**](docs/BracketsApi.md#get_all_bracket_matches) | **GET** /brackets/{bracketId}/match/{version}/all | 
*BracketsApi* | [**get_all_event_players1**](docs/BracketsApi.md#get_all_event_players1) | **POST** /brackets/director/participant/{version}/all | 
*BracketsApi* | [**get_bracket_by_id**](docs/BracketsApi.md#get_bracket_by_id) | **GET** /brackets/{version}/{bracketId} | 
*BracketsApi* | [**get_bracket_details_teams**](docs/BracketsApi.md#get_bracket_details_teams) | **GET** /brackets/{bracketId}/{version}/read | 
*BracketsApi* | [**get_bracket_match_queue**](docs/BracketsApi.md#get_bracket_match_queue) | **GET** /brackets/{bracketId}/queue/{version}/all | 
*BracketsApi* | [**get_bracket_matches**](docs/BracketsApi.md#get_bracket_matches) | **GET** /brackets/match/{version}/history | 
*BracketsApi* | [**get_bracket_matches_post**](docs/BracketsApi.md#get_bracket_matches_post) | **POST** /brackets/match/{version}/history | 
*BracketsApi* | [**get_bracket_players**](docs/BracketsApi.md#get_bracket_players) | **POST** /brackets/participant/{version}/all | 
*BracketsApi* | [**get_bracket_players1**](docs/BracketsApi.md#get_bracket_players1) | **GET** /brackets/{bracketId}/participant/{version}/all | 
*BracketsApi* | [**get_bracket_standing**](docs/BracketsApi.md#get_bracket_standing) | **GET** /brackets/{version}/standing | 
*BracketsApi* | [**get_bracket_teams**](docs/BracketsApi.md#get_bracket_teams) | **POST** /brackets/{version}/teams | 
*BracketsApi* | [**get_bracket_teams1**](docs/BracketsApi.md#get_bracket_teams1) | **GET** /brackets/{bracketId}/{version}/teams | 
*BracketsApi* | [**get_bracket_waitlisted_teams**](docs/BracketsApi.md#get_bracket_waitlisted_teams) | **POST** /brackets/{version}/waitlist/teams | 
*BracketsApi* | [**get_director_bracket_teams**](docs/BracketsApi.md#get_director_bracket_teams) | **GET** /brackets/director/{bracketId}/{version}/teams | 
*BracketsApi* | [**get_pending_confirmation**](docs/BracketsApi.md#get_pending_confirmation) | **GET** /brackets/teams/{version}/pending | 
*BracketsApi* | [**get_pending_teams_to_replace**](docs/BracketsApi.md#get_pending_teams_to_replace) | **GET** /brackets/{bracketId}/director/teams/pending/{version}/all | 
*BracketsApi* | [**get_registration_details**](docs/BracketsApi.md#get_registration_details) | **GET** /brackets/{bracketId}/participant/{version}/details | 
*BracketsApi* | [**get_unmatched_players**](docs/BracketsApi.md#get_unmatched_players) | **POST** /brackets/participant/unmatched/{version}/all | 
*BracketsApi* | [**get_unmatched_players1**](docs/BracketsApi.md#get_unmatched_players1) | **GET** /brackets/{bracketId}/participant/unmatched/{version}/all | 
*BracketsApi* | [**get_user_brackets**](docs/BracketsApi.md#get_user_brackets) | **GET** /brackets/{version}/all | 
*BracketsApi* | [**get_user_club_role**](docs/BracketsApi.md#get_user_club_role) | **POST** /brackets/club/roles/{version}/details | 
*BracketsApi* | [**get_user_event_brackets**](docs/BracketsApi.md#get_user_event_brackets) | **GET** /brackets/director/{leagueId}/{userId}/{version}/all | 
*BracketsApi* | [**get_user_matches**](docs/BracketsApi.md#get_user_matches) | **POST** /brackets/match/participant/{version}/history | 
*BracketsApi* | [**get_valid_user_bracket_id**](docs/BracketsApi.md#get_valid_user_bracket_id) | **GET** /brackets/valid/{version}/{leagueId} | 
*BracketsApi* | [**get_waterfall_matches**](docs/BracketsApi.md#get_waterfall_matches) | **GET** /brackets/match/{bracketId}/{version}/structure | 
*BracketsApi* | [**player_withdraw**](docs/BracketsApi.md#player_withdraw) | **POST** /brackets/player/{version}/withdraw | 
*BracketsApi* | [**player_withdraw_by_director**](docs/BracketsApi.md#player_withdraw_by_director) | **POST** /brackets/director/{version}/withdraw | 
*BracketsApi* | [**process_refunds**](docs/BracketsApi.md#process_refunds) | **POST** /brackets/director/{version}/refund | 
*BracketsApi* | [**register_users_to_bracket**](docs/BracketsApi.md#register_users_to_bracket) | **POST** /brackets/director/user/{version}/add | 
*BracketsApi* | [**remove_match_from_queue**](docs/BracketsApi.md#remove_match_from_queue) | **GET** /brackets/match/{leagueMatchId}/queue/{version}/remove | 
*BracketsApi* | [**save_bracket**](docs/BracketsApi.md#save_bracket) | **PUT** /brackets/{version}/save | 
*BracketsApi* | [**save_match_seeding**](docs/BracketsApi.md#save_match_seeding) | **POST** /brackets/{version}/seed | 
*BracketsApi* | [**save_teams**](docs/BracketsApi.md#save_teams) | **POST** /brackets/director/teams/{version}/save | 
*BracketsApi* | [**seed_matches**](docs/BracketsApi.md#seed_matches) | **GET** /brackets/{version}/seed | 
*BracketsApi* | [**substitute_players**](docs/BracketsApi.md#substitute_players) | **POST** /brackets/director/participant/{version}/substitute | 
*BracketsApi* | [**switch_player**](docs/BracketsApi.md#switch_player) | **POST** /brackets/director/player/{version}/switch | 
*BracketsApi* | [**switch_teams**](docs/BracketsApi.md#switch_teams) | **POST** /brackets/director/team/{version}/switch | 
*BracketsApi* | [**switch_wait_listed**](docs/BracketsApi.md#switch_wait_listed) | **POST** /brackets/director/team/{version}/switchWaitlisted | 
*BracketsApi* | [**switch_wait_listed_teams**](docs/BracketsApi.md#switch_wait_listed_teams) | **POST** /brackets/director/teams/waitlist/{version}/update | 
*BracketsApi* | [**update_bracket_approval**](docs/BracketsApi.md#update_bracket_approval) | **GET** /brackets/approval/{version}/update | 
*ChatApi* | [**chat_token**](docs/ChatApi.md#chat_token) | **GET** /chat/{version}/token/{id} | 
*ChatApi* | [**get_self_token**](docs/ChatApi.md#get_self_token) | **GET** /chat/{version}/token/self | 
*ChatApi* | [**update_user**](docs/ChatApi.md#update_user) | **POST** /chat/{version}/update/user | 
*ClientApi* | [**get_client_name_by_key**](docs/ClientApi.md#get_client_name_by_key) | **GET** /client/{version}/{clientKey}/name | 
*ClubApi* | [**add_club**](docs/ClubApi.md#add_club) | **PUT** /club/{version}/add | 
*ClubApi* | [**add_member_admin**](docs/ClubApi.md#add_member_admin) | **PUT** /club/{clubId}/members/{version}/add | 
*ClubApi* | [**add_member_multiple_admin**](docs/ClubApi.md#add_member_multiple_admin) | **PUT** /club/{clubId}/members/{version}/multiple/add | 
*ClubApi* | [**add_member_multiple_csv_admin**](docs/ClubApi.md#add_member_multiple_csv_admin) | **PUT** /club/{clubId}/members/{version}/csv/add | 
*ClubApi* | [**add_member_request**](docs/ClubApi.md#add_member_request) | **PUT** /club/{clubId}/members/{version}/join | 
*ClubApi* | [**approve_roles**](docs/ClubApi.md#approve_roles) | **POST** /club/{clubId}/{version}/approve | 
*ClubApi* | [**assign_roles**](docs/ClubApi.md#assign_roles) | **POST** /club/{clubId}/roles/{version}/assign | 
*ClubApi* | [**club_match_history**](docs/ClubApi.md#club_match_history) | **GET** /club/{clubId}/{version}/history | 
*ClubApi* | [**club_match_history_by_filters**](docs/ClubApi.md#club_match_history_by_filters) | **POST** /club/match/{version}/history | 
*ClubApi* | [**club_save_match**](docs/ClubApi.md#club_save_match) | **PUT** /club/{clubId}/match/{version}/save | 
*ClubApi* | [**delete_club_match**](docs/ClubApi.md#delete_club_match) | **POST** /club/{clubId}/match/{version}/delete | 
*ClubApi* | [**delete_member_admin**](docs/ClubApi.md#delete_member_admin) | **DELETE** /club/{clubId}/members/{version}/remove | 
*ClubApi* | [**delete_member_request**](docs/ClubApi.md#delete_member_request) | **DELETE** /club/{clubId}/members/{version}/leave | 
*ClubApi* | [**edit_club_match**](docs/ClubApi.md#edit_club_match) | **PUT** /club/{clubId}/match/{version}/edit | 
*ClubApi* | [**get_all_club_roles**](docs/ClubApi.md#get_all_club_roles) | **GET** /club/roles/{version}/all | 
*ClubApi* | [**get_all_currency_details**](docs/ClubApi.md#get_all_currency_details) | **GET** /club/currency/{version}/all | 
*ClubApi* | [**get_all_members**](docs/ClubApi.md#get_all_members) | **POST** /club/{clubId}/members/{version}/all | 
*ClubApi* | [**get_all_members_download**](docs/ClubApi.md#get_all_members_download) | **POST** /club/{clubId}/members/{version}/all/download | 
*ClubApi* | [**get_all_roles**](docs/ClubApi.md#get_all_roles) | **GET** /club/{clubId}/roles/{version}/all | 
*ClubApi* | [**get_all_staff_members**](docs/ClubApi.md#get_all_staff_members) | **GET** /club/{clubId}/members/{version}/staff | 
*ClubApi* | [**get_club**](docs/ClubApi.md#get_club) | **GET** /club/{version}/{clubId} | 
*ClubApi* | [**get_club_pending_invites**](docs/ClubApi.md#get_club_pending_invites) | **POST** /club/{clubId}/members/{version}/pending/invites | 
*ClubApi* | [**get_club_restrictions1**](docs/ClubApi.md#get_club_restrictions1) | **POST** /club/{clubId}/{version}/restrictions | 
*ClubApi* | [**get_club_roles**](docs/ClubApi.md#get_club_roles) | **POST** /club/{clubId}/roles/{version}/user | 
*ClubApi* | [**get_club_roles_player**](docs/ClubApi.md#get_club_roles_player) | **POST** /club/{clubId}/roles/{version}/permission | 
*ClubApi* | [**get_club_roles_staff**](docs/ClubApi.md#get_club_roles_staff) | **GET** /club/roles/{version}/staff | 
*ClubApi* | [**get_clubs**](docs/ClubApi.md#get_clubs) | **GET** /club/{version}/all | 
*ClubApi* | [**get_clubs1**](docs/ClubApi.md#get_clubs1) | **POST** /club/{version}/all | 
*ClubApi* | [**get_currency_details**](docs/ClubApi.md#get_currency_details) | **GET** /club/currency/{version}/{currencyCode} | 
*ClubApi* | [**get_match**](docs/ClubApi.md#get_match) | **GET** /club/{clubId}/match/{id}/{version}/get | 
*ClubApi* | [**get_members_ranking**](docs/ClubApi.md#get_members_ranking) | **POST** /club/{clubId}/{version}/ranking | 
*ClubApi* | [**invite_single_member**](docs/ClubApi.md#invite_single_member) | **PUT** /club/{clubId}/members/{version}/invite | 
*ClubApi* | [**remove_roles**](docs/ClubApi.md#remove_roles) | **POST** /club/{clubId}/roles/{version}/remove | 
*ClubApi* | [**save_verified_club_match_csv**](docs/ClubApi.md#save_verified_club_match_csv) | **PUT** /club/{id}/match/verified/{version}/save/csv/add | 
*ClubApi* | [**save_verified_multi_club_match_csv**](docs/ClubApi.md#save_verified_multi_club_match_csv) | **PUT** /club/match/csv/add/bulk | 
*ClubApi* | [**update_approval_status**](docs/ClubApi.md#update_approval_status) | **POST** /club/{clubId}/{version}/approval | 
*ClubApi* | [**update_club**](docs/ClubApi.md#update_club) | **POST** /club/{version}/update | 
*ClubApi* | [**update_staff_members**](docs/ClubApi.md#update_staff_members) | **PUT** /club/{clubId}/members/{version}/staff | 
*EventsApi* | [**checkout_event**](docs/EventsApi.md#checkout_event) | **GET** /event/{leagueId}/{version}/checkout | 
*EventsApi* | [**delete_league**](docs/EventsApi.md#delete_league) | **DELETE** /event/{version}/{leagueId} | 
*EventsApi* | [**delete_text_content**](docs/EventsApi.md#delete_text_content) | **DELETE** /event/{version}/media | 
*EventsApi* | [**draft**](docs/EventsApi.md#draft) | **POST** /event/{version}/draft | 
*EventsApi* | [**edit_league**](docs/EventsApi.md#edit_league) | **PUT** /event/{version}/edit | 
*EventsApi* | [**end_league**](docs/EventsApi.md#end_league) | **GET** /event/{leagueId}/{version}/end | 
*EventsApi* | [**export_event_participants**](docs/EventsApi.md#export_event_participants) | **GET** /event/{leagueId}/participant/{version}/export | 
*EventsApi* | [**export_event_payments**](docs/EventsApi.md#export_event_payments) | **POST** /event/director/participant/payment/{version}/export | 
*EventsApi* | [**get_all_event_players**](docs/EventsApi.md#get_all_event_players) | **POST** /event/director/participant/{version}/all | 
*EventsApi* | [**get_city_autocomplete**](docs/EventsApi.md#get_city_autocomplete) | **GET** /event/city/{version}/autocomplete | 
*EventsApi* | [**get_club_leagues**](docs/EventsApi.md#get_club_leagues) | **GET** /event/club/{version}/{clubId} | 
*EventsApi* | [**get_league**](docs/EventsApi.md#get_league) | **GET** /event/{version}/{leagueId} | 
*EventsApi* | [**get_league_policy**](docs/EventsApi.md#get_league_policy) | **GET** /event/policy/{version}/content | 
*EventsApi* | [**get_leagues_by_user_id**](docs/EventsApi.md#get_leagues_by_user_id) | **POST** /event/{version}/user/{id} | 
*EventsApi* | [**get_my_leagues**](docs/EventsApi.md#get_my_leagues) | **POST** /event/{version}/all | 
*EventsApi* | [**join_event**](docs/EventsApi.md#join_event) | **POST** /event/{leagueId}/{version}/join | 
*EventsApi* | [**register_event1**](docs/EventsApi.md#register_event1) | **POST** /event/{leagueId}/{version}/checkout | 
*EventsApi* | [**save2**](docs/EventsApi.md#save2) | **POST** /event/{version}/save | 
*EventsApi* | [**search_leagues**](docs/EventsApi.md#search_leagues) | **POST** /event/{version}/search | 
*MatchesApi* | [**confirm_match**](docs/MatchesApi.md#confirm_match) | **POST** /match/{version}/confirm | 
*MatchesApi* | [**delete_match1**](docs/MatchesApi.md#delete_match1) | **DELETE** /match/{version}/delete/{id} | 
*MatchesApi* | [**get_dupr_performance_data**](docs/MatchesApi.md#get_dupr_performance_data) | **GET** /match/{version}/performance | 
*MatchesApi* | [**get_dupr_performance_data_user**](docs/MatchesApi.md#get_dupr_performance_data_user) | **GET** /match/{version}/performance/{id} | 
*MatchesApi* | [**get_match_expected_score**](docs/MatchesApi.md#get_match_expected_score) | **POST** /match/{version}/expected-score | 
*MatchesApi* | [**get_match_rating_simulator**](docs/MatchesApi.md#get_match_rating_simulator) | **POST** /match/{version}/rating-simulator | 
*MatchesApi* | [**get_user_match_history**](docs/MatchesApi.md#get_user_match_history) | **GET** /match/{version}/history/unauthenticated/{id} | 
*MatchesApi* | [**match_details**](docs/MatchesApi.md#match_details) | **GET** /match/{id} | 
*MatchesApi* | [**pending_match_details**](docs/MatchesApi.md#pending_match_details) | **GET** /match/{version}/pending | 
*MatchesApi* | [**save_match**](docs/MatchesApi.md#save_match) | **PUT** /match/{version}/save | 
*MatchesApi* | [**save_verified_match**](docs/MatchesApi.md#save_verified_match) | **PUT** /match/verified/{version}/save | 
*MatchesApi* | [**save_verified_match_cvs**](docs/MatchesApi.md#save_verified_match_cvs) | **PUT** /match/verified/{version}/save/csv/add | 
*MatchesApi* | [**score_formats**](docs/MatchesApi.md#score_formats) | **GET** /match/{version}/score/formats | 
*MatchesApi* | [**share_match**](docs/MatchesApi.md#share_match) | **POST** /match/{version}/share/{id}/newsfeed | 
*MatchesApi* | [**user_match_history**](docs/MatchesApi.md#user_match_history) | **GET** /match/{version}/history | 
*MatchesApi* | [**user_match_history_by_filters**](docs/MatchesApi.md#user_match_history_by_filters) | **POST** /match/{version}/history | 
*MediaApi* | [**upload**](docs/MediaApi.md#upload) | **PUT** /media/{version}/image | 
*MediaApi* | [**upload_document**](docs/MediaApi.md#upload_document) | **PUT** /media/{version}/document | 
*MiLPEventsApi* | [**get_event_info**](docs/MiLPEventsApi.md#get_event_info) | **GET** /milp/event/{version}/{id} | 
*MiLPEventsApi* | [**get_teams**](docs/MiLPEventsApi.md#get_teams) | **GET** /milp/event/{version}/{id}/teams | 
*MiLPEventsApi* | [**register_team**](docs/MiLPEventsApi.md#register_team) | **POST** /milp/event/{version}/teams/checkout | 
*MiLPEventsApi* | [**save1**](docs/MiLPEventsApi.md#save1) | **POST** /milp/event/{version}/save | 
*MiLPEventsApi* | [**search_event**](docs/MiLPEventsApi.md#search_event) | **POST** /milp/event/{version}/search | 
*MiLPTeamsApi* | [**save**](docs/MiLPTeamsApi.md#save) | **POST** /milp/teams/{version}/save | 
*OpenPlayApi* | [**accept_invitation**](docs/OpenPlayApi.md#accept_invitation) | **POST** /event/{version}/open-play/{id}/invitation/accept | 
*OpenPlayApi* | [**create**](docs/OpenPlayApi.md#create) | **POST** /event/{version}/open-play/create | 
*OpenPlayApi* | [**get_event_detail**](docs/OpenPlayApi.md#get_event_detail) | **GET** /event/{version}/open-play/{id} | 
*OpenPlayApi* | [**get_events_members**](docs/OpenPlayApi.md#get_events_members) | **GET** /event/{version}/open-play/{id}/participants | 
*OpenPlayApi* | [**get_events_near_by**](docs/OpenPlayApi.md#get_events_near_by) | **GET** /event/{version}/open-play/near-by | 
*OpenPlayApi* | [**get_invitation_by_player**](docs/OpenPlayApi.md#get_invitation_by_player) | **GET** /event/{version}/open-play/invitation/player | 
*OpenPlayApi* | [**get_waitlist_by_player**](docs/OpenPlayApi.md#get_waitlist_by_player) | **GET** /event/{version}/open-play/waitlist/player | 
*OpenPlayApi* | [**join_waitlist**](docs/OpenPlayApi.md#join_waitlist) | **POST** /event/{version}/open-play/{id}/join-waitlist | 
*OpenPlayApi* | [**register_event**](docs/OpenPlayApi.md#register_event) | **POST** /event/{version}/open-play/{id}/register | 
*OpenPlayApi* | [**reject_invitation**](docs/OpenPlayApi.md#reject_invitation) | **POST** /event/{version}/open-play/{id}/invitation/reject | 
*OpenPlayApi* | [**update**](docs/OpenPlayApi.md#update) | **PUT** /event/{version}/open-play/{id}/{version}/update | 
*OpenPlayApi* | [**withdraw_event**](docs/OpenPlayApi.md#withdraw_event) | **DELETE** /event/{version}/open-play/{id}/withdraw | 
*PaymentApi* | [**club_payment_dashboard**](docs/PaymentApi.md#club_payment_dashboard) | **GET** /payment/club/{clubId}/{version}/dashboard | 
*PaymentApi* | [**club_payment_status**](docs/PaymentApi.md#club_payment_status) | **GET** /payment/club/{clubId}/{version}/status | 
*PaymentApi* | [**club_setup_payment**](docs/PaymentApi.md#club_setup_payment) | **GET** /payment/club/{clubId}/{version}/setup | 
*PlayerRatingHistoryApi* | [**get_all_player_rating_history**](docs/PlayerRatingHistoryApi.md#get_all_player_rating_history) | **GET** /player-rating-history/{version}/all | 
*PlayerRatingHistoryApi* | [**get_player_rating_history_by_user**](docs/PlayerRatingHistoryApi.md#get_player_rating_history_by_user) | **GET** /player-rating-history/{version} | 
*PlayersApi* | [**get_player_rating_history_overtime**](docs/PlayersApi.md#get_player_rating_history_overtime) | **POST** /player/{version}/{id}/rating-history | 
*PlayersApi* | [**get_statistics1**](docs/PlayersApi.md#get_statistics1) | **GET** /player/{version}/stats/{id} | 
*PlayersApi* | [**invite**](docs/PlayersApi.md#invite) | **POST** /player/{version}/invite | 
*PlayersApi* | [**match_history**](docs/PlayersApi.md#match_history) | **GET** /player/{version}/{id}/history | 
*PlayersApi* | [**match_history_by_filters**](docs/PlayersApi.md#match_history_by_filters) | **POST** /player/{version}/{id}/history | 
*PlayersApi* | [**player_info**](docs/PlayersApi.md#player_info) | **GET** /player/{version}/{id} | 
*PlayersApi* | [**player_info_by_dupr_id**](docs/PlayersApi.md#player_info_by_dupr_id) | **POST** /player/search/byDuprId | 
*PlayersApi* | [**public_search**](docs/PlayersApi.md#public_search) | **POST** /player/{version}/search/public | 
*PlayersApi* | [**search**](docs/PlayersApi.md#search) | **POST** /player/{version}/search | 
*PlayersApi* | [**search_claim_player**](docs/PlayersApi.md#search_claim_player) | **POST** /player/{version}/claim | 
*PlayersApi* | [**unclaimed_player**](docs/PlayersApi.md#unclaimed_player) | **GET** /player/{version}/claim/{id} | 
*PlayersApi* | [**unclaimed_player_details**](docs/PlayersApi.md#unclaimed_player_details) | **POST** /player/{version}/claim/details | 
*PostReportApi* | [**get_reports**](docs/PostReportApi.md#get_reports) | **GET** /report/{version}/{status} | 
*PostReportApi* | [**report_activity**](docs/PostReportApi.md#report_activity) | **POST** /report/{version} | 
*PostReportApi* | [**report_process**](docs/PostReportApi.md#report_process) | **POST** /report/{version}/process/{reportId}/{status} | 
*PromotionCampaignsApi* | [**check_eligibility**](docs/PromotionCampaignsApi.md#check_eligibility) | **POST** /admin/promotions/eligibility | 
*PromotionCampaignsApi* | [**create_product_group**](docs/PromotionCampaignsApi.md#create_product_group) | **PUT** /admin/promotions/product | 
*PromotionCampaignsApi* | [**create_promotion**](docs/PromotionCampaignsApi.md#create_promotion) | **PUT** /admin/promotions/create | 
*PromotionCampaignsApi* | [**delete_promotion**](docs/PromotionCampaignsApi.md#delete_promotion) | **DELETE** /admin/promotions | 
*PromotionCampaignsApi* | [**get_all_products**](docs/PromotionCampaignsApi.md#get_all_products) | **GET** /admin/promotions/products | 
*PromotionCampaignsApi* | [**get_all_promotions**](docs/PromotionCampaignsApi.md#get_all_promotions) | **GET** /admin/promotions/all | 
*PromotionCampaignsApi* | [**get_eligible_promotions_by_client_key**](docs/PromotionCampaignsApi.md#get_eligible_promotions_by_client_key) | **POST** /admin/promotions/eligibility/clientKey | 
*PromotionCampaignsApi* | [**get_promotion_by_id**](docs/PromotionCampaignsApi.md#get_promotion_by_id) | **GET** /admin/promotions | 
*PromotionCampaignsApi* | [**update_promotion**](docs/PromotionCampaignsApi.md#update_promotion) | **PUT** /admin/promotions/update | 
*PublicApi* | [**get_basic_info**](docs/PublicApi.md#get_basic_info) | **GET** /public/user/info | 
*SocialMediaApi* | [**delete_provider_data**](docs/SocialMediaApi.md#delete_provider_data) | **POST** /social/{version}/{provider}/delete | 
*SocialMediaApi* | [**get_instagram_login**](docs/SocialMediaApi.md#get_instagram_login) | **GET** /social/{version}/instagram/login | 
*SocialMediaApi* | [**get_login_detail**](docs/SocialMediaApi.md#get_login_detail) | **GET** /social/{version}/login | 
*SocialMediaApi* | [**get_share_messages**](docs/SocialMediaApi.md#get_share_messages) | **GET** /social/share/{version}/message | 
*SocialMediaApi* | [**update_social_login_details**](docs/SocialMediaApi.md#update_social_login_details) | **PUT** /social/{version}/login | 
*StripeApi* | [**account_charge_updates**](docs/StripeApi.md#account_charge_updates) | **POST** /stripe/account/{version}/charge | 
*StripeApi* | [**account_checkout_updates**](docs/StripeApi.md#account_checkout_updates) | **POST** /stripe/account/{version}/checkout | 
*StripeApi* | [**charge_updates**](docs/StripeApi.md#charge_updates) | **POST** /stripe/{version}/charge | 
*StripeApi* | [**checkout_account_payment_intent**](docs/StripeApi.md#checkout_account_payment_intent) | **POST** /stripe/account/{version}/payment-intent | 
*StripeApi* | [**checkout_payment_intent**](docs/StripeApi.md#checkout_payment_intent) | **POST** /stripe/{version}/payment-intent | 
*StripeApi* | [**checkout_updates**](docs/StripeApi.md#checkout_updates) | **POST** /stripe/{version}/checkout | 
*StripeApi* | [**club_account_updates**](docs/StripeApi.md#club_account_updates) | **POST** /stripe/account/{version}/updated | 
*StripeApi* | [**invoice_updates**](docs/StripeApi.md#invoice_updates) | **POST** /stripe/{version}/invoices | 
*StripeApi* | [**subscription_updates**](docs/StripeApi.md#subscription_updates) | **POST** /stripe/{version}/subscriptions | 
*SubscriptionsControllerApi* | [**create_customer_portal_session**](docs/SubscriptionsControllerApi.md#create_customer_portal_session) | **POST** /subscription/manage | 
*SubscriptionsControllerApi* | [**get_active_products**](docs/SubscriptionsControllerApi.md#get_active_products) | **POST** /subscription/checkout/products/active | 
*SubscriptionsControllerApi* | [**get_customer_status**](docs/SubscriptionsControllerApi.md#get_customer_status) | **GET** /subscription | 
*SubscriptionsControllerApi* | [**get_session_payment_status**](docs/SubscriptionsControllerApi.md#get_session_payment_status) | **POST** /subscription/checkout/session/status | 
*SubscriptionsControllerApi* | [**get_subscriptions**](docs/SubscriptionsControllerApi.md#get_subscriptions) | **POST** /subscription/active | 
*SubscriptionsControllerApi* | [**track_successful_payment**](docs/SubscriptionsControllerApi.md#track_successful_payment) | **POST** /subscription/track | 
*UserApi* | [**delete**](docs/UserApi.md#delete) | **DELETE** /notifications/history | 
*UserApi* | [**delete_user1**](docs/UserApi.md#delete_user1) | **DELETE** /user/{version}/delete | 
*UserApi* | [**get_calculated_statistics**](docs/UserApi.md#get_calculated_statistics) | **GET** /user/calculated/{version}/stats/{id} | 
*UserApi* | [**get_club_membership**](docs/UserApi.md#get_club_membership) | **GET** /user/club/membership | 
*UserApi* | [**get_compliance_data**](docs/UserApi.md#get_compliance_data) | **GET** /user/{version}/compliance | 
*UserApi* | [**get_profile**](docs/UserApi.md#get_profile) | **GET** /user/{version}/profile | 
*UserApi* | [**get_rating**](docs/UserApi.md#get_rating) | **GET** /user/{version}/rating | 
*UserApi* | [**get_settings**](docs/UserApi.md#get_settings) | **GET** /user/{version}/settings | 
*UserApi* | [**get_sponsor_logo**](docs/UserApi.md#get_sponsor_logo) | **GET** /user/{version}/sponsor | 
*UserApi* | [**get_statistics**](docs/UserApi.md#get_statistics) | **GET** /user/{version}/stats | 
*UserApi* | [**get_user_initialization_information**](docs/UserApi.md#get_user_initialization_information) | **GET** /user/{version}/initialization/{userId} | 
*UserApi* | [**get_user_initialization_information_bulk**](docs/UserApi.md#get_user_initialization_information_bulk) | **POST** /user/{version}/initialization/bulk | 
*UserApi* | [**get_verfied_statistics**](docs/UserApi.md#get_verfied_statistics) | **GET** /user/verified/{version}/stats | 
*UserApi* | [**history**](docs/UserApi.md#history) | **GET** /notifications/history | 
*UserApi* | [**is_sole_director**](docs/UserApi.md#is_sole_director) | **GET** /user/{version}/sole_director | 
*UserApi* | [**logout**](docs/UserApi.md#logout) | **POST** /user/{version}/logout | 
*UserApi* | [**reset_password**](docs/UserApi.md#reset_password) | **POST** /user/password/{version}/reset | 
*UserApi* | [**send_email_verification_link**](docs/UserApi.md#send_email_verification_link) | **POST** /user/email/verify/{version}/initiate | 
*UserApi* | [**send_phone_otp**](docs/UserApi.md#send_phone_otp) | **POST** /user/phone/{version}/resend | 
*UserApi* | [**send_verification_email**](docs/UserApi.md#send_verification_email) | **POST** /user/email/{version}/resend | 
*UserApi* | [**update_lucra_connection**](docs/UserApi.md#update_lucra_connection) | **PUT** /user/{version}/lucra-connect | 
*UserApi* | [**update_preferences**](docs/UserApi.md#update_preferences) | **PUT** /user/{version}/preferences | 
*UserApi* | [**update_profile**](docs/UserApi.md#update_profile) | **PUT** /user/{version}/profile | 
*UserApi* | [**update_settings**](docs/UserApi.md#update_settings) | **PUT** /user/{version}/settings | 
*UserApi* | [**verify_captcha**](docs/UserApi.md#verify_captcha) | **POST** /user/open/captcha/{version}/verify | 
*UserApi* | [**verify_email_address**](docs/UserApi.md#verify_email_address) | **POST** /user/email/{version}/verify | 
*UserApi* | [**verify_phone_number**](docs/UserApi.md#verify_phone_number) | **POST** /user/phone/{version}/verify | 
*UserSubscriptionsApi* | [**add_user_subscriptions**](docs/UserSubscriptionsApi.md#add_user_subscriptions) | **POST** /admin/user-subscriptions | 
*UserSubscriptionsApi* | [**get_all_user_subscriptions**](docs/UserSubscriptionsApi.md#get_all_user_subscriptions) | **GET** /admin/user-subscriptions | 
*UserSubscriptionsApi* | [**remove_user_subscriptions**](docs/UserSubscriptionsApi.md#remove_user_subscriptions) | **DELETE** /admin/user-subscriptions/{id} | 
*UserSubscriptionsApi* | [**update_user_subscriptions**](docs/UserSubscriptionsApi.md#update_user_subscriptions) | **PUT** /admin/user-subscriptions/{id} | 
*RootPathControllerApi* | [**app_ads**](docs/RootPathControllerApi.md#app_ads) | **GET** /app-ads.txt | 


## Documentation For Models

 - [AccountLinkResponse](docs/AccountLinkResponse.md)
 - [AccountStatusResponse](docs/AccountStatusResponse.md)
 - [ActivityUser](docs/ActivityUser.md)
 - [AddClientKeyRequest](docs/AddClientKeyRequest.md)
 - [AddPartnerRequest](docs/AddPartnerRequest.md)
 - [Address](docs/Address.md)
 - [AddressComponent](docs/AddressComponent.md)
 - [AddressRequest](docs/AddressRequest.md)
 - [AddressResponse](docs/AddressResponse.md)
 - [AdjustRatingRequest](docs/AdjustRatingRequest.md)
 - [AdminGrantEntitlementByDuprIdRequest](docs/AdminGrantEntitlementByDuprIdRequest.md)
 - [AdminUserProfile](docs/AdminUserProfile.md)
 - [AgeFilter](docs/AgeFilter.md)
 - [AgeRangeFilter](docs/AgeRangeFilter.md)
 - [AnnouncementContent](docs/AnnouncementContent.md)
 - [AnnouncementHistoryRequest](docs/AnnouncementHistoryRequest.md)
 - [AnnouncementsNotifications](docs/AnnouncementsNotifications.md)
 - [ArrayWrapperActivityUser](docs/ArrayWrapperActivityUser.md)
 - [ArrayWrapperBracketResponse](docs/ArrayWrapperBracketResponse.md)
 - [ArrayWrapperClubListingResponse](docs/ArrayWrapperClubListingResponse.md)
 - [ArrayWrapperCurrencyDetailsResponse](docs/ArrayWrapperCurrencyDetailsResponse.md)
 - [ArrayWrapperDuplicatedAccountResponse](docs/ArrayWrapperDuplicatedAccountResponse.md)
 - [ArrayWrapperGeocodingResult](docs/ArrayWrapperGeocodingResult.md)
 - [ArrayWrapperInformativeBannerResponce](docs/ArrayWrapperInformativeBannerResponce.md)
 - [ArrayWrapperLeagueMatchResponse](docs/ArrayWrapperLeagueMatchResponse.md)
 - [ArrayWrapperLeagueTeamsResponse](docs/ArrayWrapperLeagueTeamsResponse.md)
 - [ArrayWrapperLong](docs/ArrayWrapperLong.md)
 - [ArrayWrapperMatchRound](docs/ArrayWrapperMatchRound.md)
 - [ArrayWrapperMiLPTeamDivision](docs/ArrayWrapperMiLPTeamDivision.md)
 - [ArrayWrapperObject](docs/ArrayWrapperObject.md)
 - [ArrayWrapperPendingTeamsResponse](docs/ArrayWrapperPendingTeamsResponse.md)
 - [ArrayWrapperPlayerInitializationDataResponse](docs/ArrayWrapperPlayerInitializationDataResponse.md)
 - [ArrayWrapperPlayerInitializationProgressResponse](docs/ArrayWrapperPlayerInitializationProgressResponse.md)
 - [ArrayWrapperPostReactionResponse](docs/ArrayWrapperPostReactionResponse.md)
 - [ArrayWrapperPostResponse](docs/ArrayWrapperPostResponse.md)
 - [ArrayWrapperReaction](docs/ArrayWrapperReaction.md)
 - [ArrayWrapperRoleResponse](docs/ArrayWrapperRoleResponse.md)
 - [ArrayWrapperScoreFormatResponse](docs/ArrayWrapperScoreFormatResponse.md)
 - [ArrayWrapperString](docs/ArrayWrapperString.md)
 - [ArrayWrapperSwitchBracketResponse](docs/ArrayWrapperSwitchBracketResponse.md)
 - [AssignRoleRequest](docs/AssignRoleRequest.md)
 - [Attribute](docs/Attribute.md)
 - [AuthResponse](docs/AuthResponse.md)
 - [AutocompletePrediction](docs/AutocompletePrediction.md)
 - [AutocompleteStructuredFormatting](docs/AutocompleteStructuredFormatting.md)
 - [BannerContent](docs/BannerContent.md)
 - [BannerContentResponce](docs/BannerContentResponce.md)
 - [BasicInfo](docs/BasicInfo.md)
 - [BasicUserInfo](docs/BasicUserInfo.md)
 - [BatchGetClientsRequest](docs/BatchGetClientsRequest.md)
 - [BatchPlayerRatingProvisionalRequest](docs/BatchPlayerRatingProvisionalRequest.md)
 - [BatchPlayerRatingRequest](docs/BatchPlayerRatingRequest.md)
 - [Benefactor](docs/Benefactor.md)
 - [Bounds](docs/Bounds.md)
 - [BracketClubRoleResponse](docs/BracketClubRoleResponse.md)
 - [BracketDetailsResponse](docs/BracketDetailsResponse.md)
 - [BracketMatchRequest](docs/BracketMatchRequest.md)
 - [BracketPlayerSwitchWaitListedRequest](docs/BracketPlayerSwitchWaitListedRequest.md)
 - [BracketRefundRequest](docs/BracketRefundRequest.md)
 - [BracketRequest](docs/BracketRequest.md)
 - [BracketResponse](docs/BracketResponse.md)
 - [BracketSearchTeamsRequest](docs/BracketSearchTeamsRequest.md)
 - [BracketTeamSort](docs/BracketTeamSort.md)
 - [BracketUnmatchedPlayerSort](docs/BracketUnmatchedPlayerSort.md)
 - [BulkCoppaEmailRequest](docs/BulkCoppaEmailRequest.md)
 - [BulkSetClubRestrictionsRequest](docs/BulkSetClubRestrictionsRequest.md)
 - [CalculateMatchesRange](docs/CalculateMatchesRange.md)
 - [ChangeEmailAdminRequest](docs/ChangeEmailAdminRequest.md)
 - [ChangeRoleRequest](docs/ChangeRoleRequest.md)
 - [ChatTokenResponse](docs/ChatTokenResponse.md)
 - [CheckInLocation](docs/CheckInLocation.md)
 - [CheckPromotionEligibilityRequest](docs/CheckPromotionEligibilityRequest.md)
 - [ClaimPlayerRatingFilter](docs/ClaimPlayerRatingFilter.md)
 - [ClaimPlayerSearchFilter](docs/ClaimPlayerSearchFilter.md)
 - [ClaimPlayerSearchRequest](docs/ClaimPlayerSearchRequest.md)
 - [ClaimPlayerSearchSort](docs/ClaimPlayerSearchSort.md)
 - [Club](docs/Club.md)
 - [ClubActorResponse](docs/ClubActorResponse.md)
 - [ClubCurrencyRequest](docs/ClubCurrencyRequest.md)
 - [ClubListingResponse](docs/ClubListingResponse.md)
 - [ClubMatchFilters](docs/ClubMatchFilters.md)
 - [ClubMatchHistoryRequest](docs/ClubMatchHistoryRequest.md)
 - [ClubMatchSort](docs/ClubMatchSort.md)
 - [ClubMemberAddRequest](docs/ClubMemberAddRequest.md)
 - [ClubMemberManyResponse](docs/ClubMemberManyResponse.md)
 - [ClubMemberRankingResponse](docs/ClubMemberRankingResponse.md)
 - [ClubMemberResponse](docs/ClubMemberResponse.md)
 - [ClubMembersAgeFilter](docs/ClubMembersAgeFilter.md)
 - [ClubMembersRatingFilter](docs/ClubMembersRatingFilter.md)
 - [ClubMembersRatingRange](docs/ClubMembersRatingRange.md)
 - [ClubMembersSearchFilter](docs/ClubMembersSearchFilter.md)
 - [ClubMembersSearchRequest](docs/ClubMembersSearchRequest.md)
 - [ClubMembersSearchSort](docs/ClubMembersSearchSort.md)
 - [ClubRequest](docs/ClubRequest.md)
 - [ClubResponse](docs/ClubResponse.md)
 - [ClubRevenueModelRequest](docs/ClubRevenueModelRequest.md)
 - [ClubRole](docs/ClubRole.md)
 - [ClubRoleResponse](docs/ClubRoleResponse.md)
 - [ClubSearch](docs/ClubSearch.md)
 - [ClubSettings](docs/ClubSettings.md)
 - [ClubType](docs/ClubType.md)
 - [ClubTypeResponse](docs/ClubTypeResponse.md)
 - [ClubV1](docs/ClubV1.md)
 - [ClubV1Urn](docs/ClubV1Urn.md)
 - [Component](docs/Component.md)
 - [ConfirmTeamRequest](docs/ConfirmTeamRequest.md)
 - [ContentRequest](docs/ContentRequest.md)
 - [ContentResponse](docs/ContentResponse.md)
 - [CreateBannerRequest](docs/CreateBannerRequest.md)
 - [CreateClientRequest](docs/CreateClientRequest.md)
 - [CreateClientResponse](docs/CreateClientResponse.md)
 - [CreateClubsRequest](docs/CreateClubsRequest.md)
 - [CreateNewTeamRequest](docs/CreateNewTeamRequest.md)
 - [Creator](docs/Creator.md)
 - [CriteriaDefinition](docs/CriteriaDefinition.md)
 - [CurrencyDetails](docs/CurrencyDetails.md)
 - [CurrencyDetailsResponse](docs/CurrencyDetailsResponse.md)
 - [DateRange](docs/DateRange.md)
 - [DeleteEventMediaRequest](docs/DeleteEventMediaRequest.md)
 - [DeleteMatchRequest](docs/DeleteMatchRequest.md)
 - [DeletePromotionRequest](docs/DeletePromotionRequest.md)
 - [DeleteUserResponse](docs/DeleteUserResponse.md)
 - [Description](docs/Description.md)
 - [DeviceRequest](docs/DeviceRequest.md)
 - [Distance](docs/Distance.md)
 - [Division](docs/Division.md)
 - [DownloadS3Response](docs/DownloadS3Response.md)
 - [DraftBracketRequest](docs/DraftBracketRequest.md)
 - [DraftLeagueRequest](docs/DraftLeagueRequest.md)
 - [DuplicatedAccountResponse](docs/DuplicatedAccountResponse.md)
 - [DuplicatedPlayer](docs/DuplicatedPlayer.md)
 - [DuprDiscount](docs/DuprDiscount.md)
 - [DuprProduct](docs/DuprProduct.md)
 - [DynamicUserIdentityType](docs/DynamicUserIdentityType.md)
 - [EditBracketRequest](docs/EditBracketRequest.md)
 - [EditClubStaffRequest](docs/EditClubStaffRequest.md)
 - [EditEventTeamRequest](docs/EditEventTeamRequest.md)
 - [EditLeagueRequest](docs/EditLeagueRequest.md)
 - [EditMatchRequest](docs/EditMatchRequest.md)
 - [EditPartnerRequest](docs/EditPartnerRequest.md)
 - [EditScoreRequest](docs/EditScoreRequest.md)
 - [EditWaitListRequest](docs/EditWaitListRequest.md)
 - [EmailExistRequest](docs/EmailExistRequest.md)
 - [EpochSecondsTimestampV1Urn](docs/EpochSecondsTimestampV1Urn.md)
 - [Error](docs/Error.md)
 - [EventAnnouncementRequest](docs/EventAnnouncementRequest.md)
 - [EventAnnouncementsResponse](docs/EventAnnouncementsResponse.md)
 - [EventFilter](docs/EventFilter.md)
 - [EventRefundRequest](docs/EventRefundRequest.md)
 - [ExcludeClubMembers](docs/ExcludeClubMembers.md)
 - [ExportEventPaymentRequest](docs/ExportEventPaymentRequest.md)
 - [ExternalFilterLocation](docs/ExternalFilterLocation.md)
 - [FacebookRequest](docs/FacebookRequest.md)
 - [Feed](docs/Feed.md)
 - [Filters](docs/Filters.md)
 - [FollowingInfo](docs/FollowingInfo.md)
 - [ForfeitMatchRequest](docs/ForfeitMatchRequest.md)
 - [ForfeitTeamRequest](docs/ForfeitTeamRequest.md)
 - [GameTrendResponse](docs/GameTrendResponse.md)
 - [GeoPoint](docs/GeoPoint.md)
 - [GeocodingResult](docs/GeocodingResult.md)
 - [Geometry](docs/Geometry.md)
 - [GetActiveProductsResponse](docs/GetActiveProductsResponse.md)
 - [GetClientPermissionsRequest](docs/GetClientPermissionsRequest.md)
 - [GetClubRestrictionsRequest](docs/GetClubRestrictionsRequest.md)
 - [GetClubSettingsRequest](docs/GetClubSettingsRequest.md)
 - [GetEligiblePromotionsRequest](docs/GetEligiblePromotionsRequest.md)
 - [GetProductsForClientKeyRequest](docs/GetProductsForClientKeyRequest.md)
 - [GetPromotionsRequest](docs/GetPromotionsRequest.md)
 - [GetStreamCommentResponse](docs/GetStreamCommentResponse.md)
 - [GetStreamCommentResponseV1Urn](docs/GetStreamCommentResponseV1Urn.md)
 - [GetStreamPostResponse](docs/GetStreamPostResponse.md)
 - [GetStreamPostResponseV1Urn](docs/GetStreamPostResponseV1Urn.md)
 - [GetStripeSessionRequest](docs/GetStripeSessionRequest.md)
 - [GrantedAuthority](docs/GrantedAuthority.md)
 - [History](docs/History.md)
 - [IdPayload](docs/IdPayload.md)
 - [IdsListRequest](docs/IdsListRequest.md)
 - [InformativeBannerResponce](docs/InformativeBannerResponce.md)
 - [InstagramRequest](docs/InstagramRequest.md)
 - [InviteRequest](docs/InviteRequest.md)
 - [JoinLeagueRequest](docs/JoinLeagueRequest.md)
 - [JoinLeagueResponse](docs/JoinLeagueResponse.md)
 - [LatLng](docs/LatLng.md)
 - [LeagueContactDetailResponse](docs/LeagueContactDetailResponse.md)
 - [LeagueContentRequest](docs/LeagueContentRequest.md)
 - [LeagueContentResponse](docs/LeagueContentResponse.md)
 - [LeagueFeesRequest](docs/LeagueFeesRequest.md)
 - [LeagueFilter](docs/LeagueFilter.md)
 - [LeagueMatchConfirmRequest](docs/LeagueMatchConfirmRequest.md)
 - [LeagueMatchRequest](docs/LeagueMatchRequest.md)
 - [LeagueMatchResponse](docs/LeagueMatchResponse.md)
 - [LeagueRequest](docs/LeagueRequest.md)
 - [LeagueResponse](docs/LeagueResponse.md)
 - [LeagueStandingResponse](docs/LeagueStandingResponse.md)
 - [LeagueTeams](docs/LeagueTeams.md)
 - [LeagueTeamsResponse](docs/LeagueTeamsResponse.md)
 - [LoginRequest](docs/LoginRequest.md)
 - [LogoutRequest](docs/LogoutRequest.md)
 - [MILPDivisionRequest](docs/MILPDivisionRequest.md)
 - [MILPEventOrganizerRequest](docs/MILPEventOrganizerRequest.md)
 - [Match](docs/Match.md)
 - [MatchConfirmRequest](docs/MatchConfirmRequest.md)
 - [MatchExpectedScoreRequest](docs/MatchExpectedScoreRequest.md)
 - [MatchExpectedScoreResponse](docs/MatchExpectedScoreResponse.md)
 - [MatchFilters](docs/MatchFilters.md)
 - [MatchInfo](docs/MatchInfo.md)
 - [MatchRatingSimulatorRequest](docs/MatchRatingSimulatorRequest.md)
 - [MatchRatings](docs/MatchRatings.md)
 - [MatchRequest](docs/MatchRequest.md)
 - [MatchResponse](docs/MatchResponse.md)
 - [MatchRound](docs/MatchRound.md)
 - [MatchSearchRequest](docs/MatchSearchRequest.md)
 - [MatchSort](docs/MatchSort.md)
 - [MatchUpdateRequest](docs/MatchUpdateRequest.md)
 - [MatchedSubstring](docs/MatchedSubstring.md)
 - [MatchesReassignRequest](docs/MatchesReassignRequest.md)
 - [MediaResponse](docs/MediaResponse.md)
 - [MemberRanking](docs/MemberRanking.md)
 - [MemberRequest](docs/MemberRequest.md)
 - [MergeUsersRequest](docs/MergeUsersRequest.md)
 - [MergeUsersResponse](docs/MergeUsersResponse.md)
 - [MiLPEvent](docs/MiLPEvent.md)
 - [MiLPEventRequest](docs/MiLPEventRequest.md)
 - [MiLPEventSearchRequest](docs/MiLPEventSearchRequest.md)
 - [MiLPRegisterTeamRequest](docs/MiLPRegisterTeamRequest.md)
 - [MiLPTeam](docs/MiLPTeam.md)
 - [MiLPTeamDivision](docs/MiLPTeamDivision.md)
 - [MiLPTeamRequest](docs/MiLPTeamRequest.md)
 - [MyLeagueRequest](docs/MyLeagueRequest.md)
 - [NotificationHistoryResponse](docs/NotificationHistoryResponse.md)
 - [NotificationHistoryResponseDataValue](docs/NotificationHistoryResponseDataValue.md)
 - [OpenPlayCreateRequest](docs/OpenPlayCreateRequest.md)
 - [OpenPlayEvent](docs/OpenPlayEvent.md)
 - [OpenPlayEventWaitlist](docs/OpenPlayEventWaitlist.md)
 - [OpenPlayMember](docs/OpenPlayMember.md)
 - [OpenPlayUpdateRequest](docs/OpenPlayUpdateRequest.md)
 - [OverviewResponse](docs/OverviewResponse.md)
 - [PageBracketResponse](docs/PageBracketResponse.md)
 - [PageClubMemberResponse](docs/PageClubMemberResponse.md)
 - [PageClubResponse](docs/PageClubResponse.md)
 - [PageEventAnnouncementsResponse](docs/PageEventAnnouncementsResponse.md)
 - [PageLeagueMatchResponse](docs/PageLeagueMatchResponse.md)
 - [PageLeagueResponse](docs/PageLeagueResponse.md)
 - [PageLeagueStandingResponse](docs/PageLeagueStandingResponse.md)
 - [PageLeagueTeamsResponse](docs/PageLeagueTeamsResponse.md)
 - [PageMatchResponse](docs/PageMatchResponse.md)
 - [PageMemberRanking](docs/PageMemberRanking.md)
 - [PageMiLPEvent](docs/PageMiLPEvent.md)
 - [PageOpenPlayEvent](docs/PageOpenPlayEvent.md)
 - [PageOpenPlayMember](docs/PageOpenPlayMember.md)
 - [PagePlayerPaymentResponse](docs/PagePlayerPaymentResponse.md)
 - [PagePlayerQueue](docs/PagePlayerQueue.md)
 - [PagePlayerRatingHistory](docs/PagePlayerRatingHistory.md)
 - [PagePlayerResponse](docs/PagePlayerResponse.md)
 - [PagePostReport](docs/PagePostReport.md)
 - [PageUnclaimedPlayerResponse](docs/PageUnclaimedPlayerResponse.md)
 - [PageUserLookupResponse](docs/PageUserLookupResponse.md)
 - [PageUserSubscription](docs/PageUserSubscription.md)
 - [PageUserSuggestion](docs/PageUserSuggestion.md)
 - [PairIntegerInteger](docs/PairIntegerInteger.md)
 - [Participant](docs/Participant.md)
 - [PaymentDetailsResponse](docs/PaymentDetailsResponse.md)
 - [PaymentReportRequest](docs/PaymentReportRequest.md)
 - [PendingTeamsResponse](docs/PendingTeamsResponse.md)
 - [Permission](docs/Permission.md)
 - [Player](docs/Player.md)
 - [PlayerInitializationDataResponse](docs/PlayerInitializationDataResponse.md)
 - [PlayerInitializationProgressResponse](docs/PlayerInitializationProgressResponse.md)
 - [PlayerPaymentResponse](docs/PlayerPaymentResponse.md)
 - [PlayerProfileRequest](docs/PlayerProfileRequest.md)
 - [PlayerQueue](docs/PlayerQueue.md)
 - [PlayerRatingHistory](docs/PlayerRatingHistory.md)
 - [PlayerRatingHistoryOvertimeRequest](docs/PlayerRatingHistoryOvertimeRequest.md)
 - [PlayerRatingOvertime](docs/PlayerRatingOvertime.md)
 - [PlayerRatingResponse](docs/PlayerRatingResponse.md)
 - [PlayerRatingUpdateRequest](docs/PlayerRatingUpdateRequest.md)
 - [PlayerResponse](docs/PlayerResponse.md)
 - [PlayerSignUpRequest](docs/PlayerSignUpRequest.md)
 - [PlayerSort](docs/PlayerSort.md)
 - [PlayerStatisticsUpdateRequest](docs/PlayerStatisticsUpdateRequest.md)
 - [PlusCode](docs/PlusCode.md)
 - [PolicyDetailsResponse](docs/PolicyDetailsResponse.md)
 - [PostMatchRating](docs/PostMatchRating.md)
 - [PostReactionResponse](docs/PostReactionResponse.md)
 - [PostReport](docs/PostReport.md)
 - [PostRequest](docs/PostRequest.md)
 - [PostResponse](docs/PostResponse.md)
 - [PreCalculatedUserStatisticsResponse](docs/PreCalculatedUserStatisticsResponse.md)
 - [PreMatchRatingAndImpact](docs/PreMatchRatingAndImpact.md)
 - [ProductRequest](docs/ProductRequest.md)
 - [Promotion](docs/Promotion.md)
 - [PromotionCampaign](docs/PromotionCampaign.md)
 - [PromotionCampaignRequest](docs/PromotionCampaignRequest.md)
 - [PromotionProductCreateRequest](docs/PromotionProductCreateRequest.md)
 - [ProvisionalRating](docs/ProvisionalRating.md)
 - [RatingCoach](docs/RatingCoach.md)
 - [RatingFilter](docs/RatingFilter.md)
 - [RatingLeaderboardRequest](docs/RatingLeaderboardRequest.md)
 - [RatingOverviewResponse](docs/RatingOverviewResponse.md)
 - [RatingRange](docs/RatingRange.md)
 - [RatingsOverviewResponse](docs/RatingsOverviewResponse.md)
 - [RatingsUnclaimedPlayerResponse](docs/RatingsUnclaimedPlayerResponse.md)
 - [ReactDeleteRequest](docs/ReactDeleteRequest.md)
 - [ReactRequest](docs/ReactRequest.md)
 - [Reaction](docs/Reaction.md)
 - [RegisterToBracketRequest](docs/RegisterToBracketRequest.md)
 - [RegisterUserRequest](docs/RegisterUserRequest.md)
 - [RegisteredEventAdminRequest](docs/RegisteredEventAdminRequest.md)
 - [RegistrationResponse](docs/RegistrationResponse.md)
 - [RemoveAllClubRestrictionsRequest](docs/RemoveAllClubRestrictionsRequest.md)
 - [RemoveClubRestrictionsRequest](docs/RemoveClubRestrictionsRequest.md)
 - [ReportRequest](docs/ReportRequest.md)
 - [ResetPasswordRequest](docs/ResetPasswordRequest.md)
 - [ResultBasicInfo](docs/ResultBasicInfo.md)
 - [ResultBoolean](docs/ResultBoolean.md)
 - [ResultGetActiveProductsResponse](docs/ResultGetActiveProductsResponse.md)
 - [ResultString](docs/ResultString.md)
 - [ResultUnclaimedPlayerDetailsResponse](docs/ResultUnclaimedPlayerDetailsResponse.md)
 - [ResultUnit](docs/ResultUnit.md)
 - [ResultUserByDuprIdResponse](docs/ResultUserByDuprIdResponse.md)
 - [ResultUserComplianceDataResponse](docs/ResultUserComplianceDataResponse.md)
 - [RevenueModel](docs/RevenueModel.md)
 - [Role](docs/Role.md)
 - [RoleResponse](docs/RoleResponse.md)
 - [S3Object](docs/S3Object.md)
 - [SaveVerifiedMatchCVSRequest](docs/SaveVerifiedMatchCVSRequest.md)
 - [ScoreFormat](docs/ScoreFormat.md)
 - [ScoreFormatResponse](docs/ScoreFormatResponse.md)
 - [SearchFilter](docs/SearchFilter.md)
 - [SearchLeaguePlayerRequest](docs/SearchLeaguePlayerRequest.md)
 - [SearchLeaguesRequest](docs/SearchLeaguesRequest.md)
 - [SearchRequest](docs/SearchRequest.md)
 - [SearchUnmatchedPlayersRequest](docs/SearchUnmatchedPlayersRequest.md)
 - [SeedMatch](docs/SeedMatch.md)
 - [SendOtpRequest](docs/SendOtpRequest.md)
 - [SessionResponse](docs/SessionResponse.md)
 - [SetClubRestrictionsRequest](docs/SetClubRestrictionsRequest.md)
 - [SetClubSettingsRequest](docs/SetClubSettingsRequest.md)
 - [SetDuprIdsInactiveRequest](docs/SetDuprIdsInactiveRequest.md)
 - [ShareMatchRequest](docs/ShareMatchRequest.md)
 - [SignUpRequest](docs/SignUpRequest.md)
 - [SignupBatchRequest](docs/SignupBatchRequest.md)
 - [SingleWrapperAccountLinkResponse](docs/SingleWrapperAccountLinkResponse.md)
 - [SingleWrapperAccountStatusResponse](docs/SingleWrapperAccountStatusResponse.md)
 - [SingleWrapperAdminUserProfile](docs/SingleWrapperAdminUserProfile.md)
 - [SingleWrapperAuthResponse](docs/SingleWrapperAuthResponse.md)
 - [SingleWrapperAutocompletePrediction](docs/SingleWrapperAutocompletePrediction.md)
 - [SingleWrapperBoolean](docs/SingleWrapperBoolean.md)
 - [SingleWrapperBracketClubRoleResponse](docs/SingleWrapperBracketClubRoleResponse.md)
 - [SingleWrapperBracketDetailsResponse](docs/SingleWrapperBracketDetailsResponse.md)
 - [SingleWrapperBracketResponse](docs/SingleWrapperBracketResponse.md)
 - [SingleWrapperChatTokenResponse](docs/SingleWrapperChatTokenResponse.md)
 - [SingleWrapperClubMemberManyResponse](docs/SingleWrapperClubMemberManyResponse.md)
 - [SingleWrapperClubMemberRankingResponse](docs/SingleWrapperClubMemberRankingResponse.md)
 - [SingleWrapperClubResponse](docs/SingleWrapperClubResponse.md)
 - [SingleWrapperCreateClientResponse](docs/SingleWrapperCreateClientResponse.md)
 - [SingleWrapperCurrencyDetailsResponse](docs/SingleWrapperCurrencyDetailsResponse.md)
 - [SingleWrapperDownloadS3Response](docs/SingleWrapperDownloadS3Response.md)
 - [SingleWrapperFollowingInfo](docs/SingleWrapperFollowingInfo.md)
 - [SingleWrapperGeocodingResult](docs/SingleWrapperGeocodingResult.md)
 - [SingleWrapperIdPayload](docs/SingleWrapperIdPayload.md)
 - [SingleWrapperJoinLeagueResponse](docs/SingleWrapperJoinLeagueResponse.md)
 - [SingleWrapperLeagueResponse](docs/SingleWrapperLeagueResponse.md)
 - [SingleWrapperLong](docs/SingleWrapperLong.md)
 - [SingleWrapperMapStringObject](docs/SingleWrapperMapStringObject.md)
 - [SingleWrapperMapStringString](docs/SingleWrapperMapStringString.md)
 - [SingleWrapperMatchResponse](docs/SingleWrapperMatchResponse.md)
 - [SingleWrapperMediaResponse](docs/SingleWrapperMediaResponse.md)
 - [SingleWrapperMergeUsersResponse](docs/SingleWrapperMergeUsersResponse.md)
 - [SingleWrapperMiLPEvent](docs/SingleWrapperMiLPEvent.md)
 - [SingleWrapperMiLPTeam](docs/SingleWrapperMiLPTeam.md)
 - [SingleWrapperOpenPlayEvent](docs/SingleWrapperOpenPlayEvent.md)
 - [SingleWrapperOpenPlayEventWaitlist](docs/SingleWrapperOpenPlayEventWaitlist.md)
 - [SingleWrapperPageBracketResponse](docs/SingleWrapperPageBracketResponse.md)
 - [SingleWrapperPageClubMemberResponse](docs/SingleWrapperPageClubMemberResponse.md)
 - [SingleWrapperPageClubResponse](docs/SingleWrapperPageClubResponse.md)
 - [SingleWrapperPageEventAnnouncementsResponse](docs/SingleWrapperPageEventAnnouncementsResponse.md)
 - [SingleWrapperPageLeagueMatchResponse](docs/SingleWrapperPageLeagueMatchResponse.md)
 - [SingleWrapperPageLeagueResponse](docs/SingleWrapperPageLeagueResponse.md)
 - [SingleWrapperPageLeagueStandingResponse](docs/SingleWrapperPageLeagueStandingResponse.md)
 - [SingleWrapperPageLeagueTeamsResponse](docs/SingleWrapperPageLeagueTeamsResponse.md)
 - [SingleWrapperPageMatchResponse](docs/SingleWrapperPageMatchResponse.md)
 - [SingleWrapperPageMiLPEvent](docs/SingleWrapperPageMiLPEvent.md)
 - [SingleWrapperPageOpenPlayEvent](docs/SingleWrapperPageOpenPlayEvent.md)
 - [SingleWrapperPageOpenPlayMember](docs/SingleWrapperPageOpenPlayMember.md)
 - [SingleWrapperPagePlayerPaymentResponse](docs/SingleWrapperPagePlayerPaymentResponse.md)
 - [SingleWrapperPagePlayerQueue](docs/SingleWrapperPagePlayerQueue.md)
 - [SingleWrapperPagePlayerRatingHistory](docs/SingleWrapperPagePlayerRatingHistory.md)
 - [SingleWrapperPagePlayerResponse](docs/SingleWrapperPagePlayerResponse.md)
 - [SingleWrapperPagePostReport](docs/SingleWrapperPagePostReport.md)
 - [SingleWrapperPageUnclaimedPlayerResponse](docs/SingleWrapperPageUnclaimedPlayerResponse.md)
 - [SingleWrapperPageUserLookupResponse](docs/SingleWrapperPageUserLookupResponse.md)
 - [SingleWrapperPageUserSuggestion](docs/SingleWrapperPageUserSuggestion.md)
 - [SingleWrapperPlayerRatingOvertime](docs/SingleWrapperPlayerRatingOvertime.md)
 - [SingleWrapperPlayerRatingResponse](docs/SingleWrapperPlayerRatingResponse.md)
 - [SingleWrapperPlayerResponse](docs/SingleWrapperPlayerResponse.md)
 - [SingleWrapperPolicyDetailsResponse](docs/SingleWrapperPolicyDetailsResponse.md)
 - [SingleWrapperPostReport](docs/SingleWrapperPostReport.md)
 - [SingleWrapperPostResponse](docs/SingleWrapperPostResponse.md)
 - [SingleWrapperPreCalculatedUserStatisticsResponse](docs/SingleWrapperPreCalculatedUserStatisticsResponse.md)
 - [SingleWrapperReaction](docs/SingleWrapperReaction.md)
 - [SingleWrapperRegistrationResponse](docs/SingleWrapperRegistrationResponse.md)
 - [SingleWrapperRevenueModel](docs/SingleWrapperRevenueModel.md)
 - [SingleWrapperRoleResponse](docs/SingleWrapperRoleResponse.md)
 - [SingleWrapperSessionResponse](docs/SingleWrapperSessionResponse.md)
 - [SingleWrapperSponsorLogoResponse](docs/SingleWrapperSponsorLogoResponse.md)
 - [SingleWrapperStaffClubMemberResponse](docs/SingleWrapperStaffClubMemberResponse.md)
 - [SingleWrapperString](docs/SingleWrapperString.md)
 - [SingleWrapperTopicResponse](docs/SingleWrapperTopicResponse.md)
 - [SingleWrapperUnclaimedPlayerResponse](docs/SingleWrapperUnclaimedPlayerResponse.md)
 - [SingleWrapperUnit](docs/SingleWrapperUnit.md)
 - [SingleWrapperUpdateClientPermissionsResponse](docs/SingleWrapperUpdateClientPermissionsResponse.md)
 - [SingleWrapperUserResponse](docs/SingleWrapperUserResponse.md)
 - [SingleWrapperUserStatisticResponse](docs/SingleWrapperUserStatisticResponse.md)
 - [SkillLevelFilter](docs/SkillLevelFilter.md)
 - [Sponsor](docs/Sponsor.md)
 - [SponsorLogoResponse](docs/SponsorLogoResponse.md)
 - [StaffClubMember](docs/StaffClubMember.md)
 - [StaffClubMemberRequest](docs/StaffClubMemberRequest.md)
 - [StaffClubMemberResponse](docs/StaffClubMemberResponse.md)
 - [StatusRequest](docs/StatusRequest.md)
 - [Subscription](docs/Subscription.md)
 - [SubscriptionResponse](docs/SubscriptionResponse.md)
 - [SubstitutePlayerRequest](docs/SubstitutePlayerRequest.md)
 - [SwitchBracketRequest](docs/SwitchBracketRequest.md)
 - [SwitchBracketResponse](docs/SwitchBracketResponse.md)
 - [SwitchTeamRequest](docs/SwitchTeamRequest.md)
 - [Team](docs/Team.md)
 - [TeamIds](docs/TeamIds.md)
 - [TeamInfo](docs/TeamInfo.md)
 - [TeamMember](docs/TeamMember.md)
 - [TeamPlayerResponse](docs/TeamPlayerResponse.md)
 - [TeamResponse](docs/TeamResponse.md)
 - [TeamUpdateRequest](docs/TeamUpdateRequest.md)
 - [TeamsResponse](docs/TeamsResponse.md)
 - [Term](docs/Term.md)
 - [TextContent](docs/TextContent.md)
 - [TimeRange](docs/TimeRange.md)
 - [TimestampResponse](docs/TimestampResponse.md)
 - [TimestampResponseAllOfTimestamp](docs/TimestampResponseAllOfTimestamp.md)
 - [TimestampUrn](docs/TimestampUrn.md)
 - [TopicRequest](docs/TopicRequest.md)
 - [TopicResponse](docs/TopicResponse.md)
 - [TrendResponse](docs/TrendResponse.md)
 - [UnclaimedPlayerDetailsRequest](docs/UnclaimedPlayerDetailsRequest.md)
 - [UnclaimedPlayerDetailsResponse](docs/UnclaimedPlayerDetailsResponse.md)
 - [UnclaimedPlayerResponse](docs/UnclaimedPlayerResponse.md)
 - [UnknownNotificationResponseV1](docs/UnknownNotificationResponseV1.md)
 - [UnknownTimestampV1Urn](docs/UnknownTimestampV1Urn.md)
 - [UpdateClientPermissionsRequest](docs/UpdateClientPermissionsRequest.md)
 - [UpdateClientPermissionsResponse](docs/UpdateClientPermissionsResponse.md)
 - [UpdateRegistrationRequest](docs/UpdateRegistrationRequest.md)
 - [UpdateUserRequest](docs/UpdateUserRequest.md)
 - [Urn](docs/Urn.md)
 - [User](docs/User.md)
 - [UserActorResponse](docs/UserActorResponse.md)
 - [UserAuthProviderRequest](docs/UserAuthProviderRequest.md)
 - [UserBracketAdminRequest](docs/UserBracketAdminRequest.md)
 - [UserByDuprIdRequest](docs/UserByDuprIdRequest.md)
 - [UserByDuprIdResponse](docs/UserByDuprIdResponse.md)
 - [UserClubRoleRequest](docs/UserClubRoleRequest.md)
 - [UserComplianceDataResponse](docs/UserComplianceDataResponse.md)
 - [UserFollow](docs/UserFollow.md)
 - [UserListRequest](docs/UserListRequest.md)
 - [UserLookupResponse](docs/UserLookupResponse.md)
 - [UserLucraRequest](docs/UserLucraRequest.md)
 - [UserMatchesRequest](docs/UserMatchesRequest.md)
 - [UserPreferencesRequest](docs/UserPreferencesRequest.md)
 - [UserPreferencesResponse](docs/UserPreferencesResponse.md)
 - [UserRequest](docs/UserRequest.md)
 - [UserResponse](docs/UserResponse.md)
 - [UserRestrictRequest](docs/UserRestrictRequest.md)
 - [UserSearchRequest](docs/UserSearchRequest.md)
 - [UserSettingsRequest](docs/UserSettingsRequest.md)
 - [UserStatisticResponse](docs/UserStatisticResponse.md)
 - [UserStatusUpdateRequest](docs/UserStatusUpdateRequest.md)
 - [UserSubscription](docs/UserSubscription.md)
 - [UserSubscriptionRequest](docs/UserSubscriptionRequest.md)
 - [UserSuggestion](docs/UserSuggestion.md)
 - [UserSuggestionRequest](docs/UserSuggestionRequest.md)
 - [UserV1](docs/UserV1.md)
 - [UserV1Urn](docs/UserV1Urn.md)
 - [VerifiedMatchRequest](docs/VerifiedMatchRequest.md)
 - [VerifyEmailRequest](docs/VerifyEmailRequest.md)
 - [VerifyOtpRequest](docs/VerifyOtpRequest.md)
 - [VerifyTokenRequest](docs/VerifyTokenRequest.md)
 - [WithdrawPlayerRequest](docs/WithdrawPlayerRequest.md)
 - [Wrapper](docs/Wrapper.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication (JWT)


## Author




